@@ -2,11 +2,12 @@
 
 #include "zm_monitor.h"
 #include "zm_signal.h"
-#include "zm_utils.h"
+#include "zm_time.h"
 
 AnalysisThread::AnalysisThread(Monitor *monitor) :
-    monitor_(monitor), terminate_(false) {
+  monitor_(monitor), terminate_(false) {
   thread_ = std::thread(&AnalysisThread::Run, this);
+  set_cpu_affinity(thread_);
 }
 
 AnalysisThread::~AnalysisThread() {
@@ -19,15 +20,25 @@ void AnalysisThread::Start() {
   terminate_ = false;
   Debug(3, "Starting analysis thread");
   thread_ = std::thread(&AnalysisThread::Run, this);
+  set_cpu_affinity(thread_);
+}
+
+void AnalysisThread::Stop() {
+  terminate_ = true;
+}
+void AnalysisThread::Join() {
+  if (thread_.joinable()) thread_.join();
 }
 
 void AnalysisThread::Run() {
   while (!(terminate_ or zm_terminate)) {
     // Some periodic updates are required for variable capturing framerate
-    if (!monitor_->Analyse()) {
+    int ret = monitor_->Analyse();
+    if (ret < 0) {
       if (!(terminate_ or zm_terminate)) {
+        // We only sleep when Analyse returns false because it is an error condition and we will spin like mad if it persists.
         Microseconds sleep_for = monitor_->Active() ? Microseconds(ZM_SAMPLE_RATE) : Microseconds(ZM_SUSPENDED_RATE);
-        Debug(2, "Sleeping for %" PRId64 "us", int64(sleep_for.count()));
+        Debug(5, "Sleeping for %" PRId64 "us", int64(sleep_for.count()));
         std::this_thread::sleep_for(sleep_for);
       }
     }
