@@ -1,17 +1,17 @@
 //
 // ZoneMinder Configuration Implementation, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
-// 
+//
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
@@ -27,8 +27,8 @@
 #include <dirent.h>
 #include <glob.h>
 
-// Note that Error and Debug calls won't actually go anywhere unless you 
-// set the relevant ENV vars because the logger gets it's setting from the 
+// Note that Error and Debug calls won't actually go anywhere unless you
+// set the relevant ENV vars because the logger gets it's setting from the
 // config.
 
 void zmLoadStaticConfig() {
@@ -39,16 +39,15 @@ void zmLoadStaticConfig() {
   // update the Config hash with those values
   DIR *configSubFolder = opendir(ZM_CONFIG_SUBDIR);
   if (configSubFolder) { // subfolder exists and is readable
-    char glob_pattern[PATH_MAX] = "";
-    snprintf(glob_pattern, sizeof(glob_pattern), "%s/*.conf", ZM_CONFIG_SUBDIR);
+    std::string glob_pattern = stringtf("%s/*.conf", ZM_CONFIG_SUBDIR);
 
     glob_t pglob;
-    int glob_status = glob(glob_pattern, 0, nullptr, &pglob);
+    int glob_status = glob(glob_pattern.c_str(), 0, nullptr, &pglob);
     if (glob_status != 0) {
       if (glob_status < 0) {
-        Error("Can't glob '%s': %s", glob_pattern, strerror(errno));
+        Error("Can't glob '%s': %s", glob_pattern.c_str(), strerror(errno));
       } else {
-        Debug(1, "Can't glob '%s': %d", glob_pattern, glob_status);
+        Debug(1, "Can't glob '%s': %d", glob_pattern.c_str(), glob_status);
       }
     } else {
       for (unsigned int i = 0; i < pglob.gl_pathc; i++) {
@@ -75,7 +74,7 @@ void zmLoadDBConfig() {
       std::string sql = stringtf("SELECT `Id` FROM `Servers` WHERE `Name`='%s'",
                                  staticConfig.SERVER_NAME.c_str());
       zmDbRow dbrow;
-      if (dbrow.fetch(sql.c_str())) {
+      if (dbrow.fetch(sql)) {
         staticConfig.SERVER_ID = atoi(dbrow[0]);
       } else {
         Fatal("Can't get ServerId for Server %s", staticConfig.SERVER_NAME.c_str());
@@ -87,7 +86,7 @@ void zmLoadDBConfig() {
     std::string sql = stringtf("SELECT `Name` FROM `Servers` WHERE `Id`='%d'", staticConfig.SERVER_ID);
 
     zmDbRow dbrow;
-    if (dbrow.fetch(sql.c_str())) {
+    if (dbrow.fetch(sql)) {
       staticConfig.SERVER_NAME = std::string(dbrow[0]);
     } else {
       Fatal("Can't get ServerName for Server ID %d", staticConfig.SERVER_ID);
@@ -100,13 +99,10 @@ void zmLoadDBConfig() {
     }
   }
 
-  snprintf(staticConfig.capture_file_format, sizeof(staticConfig.capture_file_format), "%%s/%%0%dd-capture.jpg",
-           config.event_image_digits);
-  snprintf(staticConfig.analyse_file_format, sizeof(staticConfig.analyse_file_format), "%%s/%%0%dd-analyse.jpg",
-           config.event_image_digits);
-  snprintf(staticConfig.general_file_format, sizeof(staticConfig.general_file_format), "%%s/%%0%dd-%%s",
-           config.event_image_digits);
-  snprintf(staticConfig.video_file_format, sizeof(staticConfig.video_file_format), "%%s/%%s");
+  staticConfig.capture_file_format = stringtf("%%s/%%0%dd-capture.jpg", config.event_image_digits);
+  staticConfig.analyse_file_format = stringtf("%%s/%%0%dd-analyse.jpg", config.event_image_digits);
+  staticConfig.general_file_format = stringtf("%%s/%%0%dd-%%s", config.event_image_digits);
+  staticConfig.video_file_format = "%s/%s";
 }
 
 void process_configfile(char const *configFile) {
@@ -184,6 +180,8 @@ void process_configfile(char const *configFile) {
       staticConfig.SERVER_ID = atoi(val_ptr);
     else if ( strcasecmp(name_ptr, "ZM_DIR_EVENTS") == 0 )
       staticConfig.DIR_EVENTS = std::string(val_ptr);
+    else if ( strcasecmp(name_ptr, "ZM_DIR_MODELS") == 0 )
+      staticConfig.DIR_MODELS = std::string(val_ptr);
     else if ( strcasecmp(name_ptr, "ZM_DIR_SOUNDS") == 0 )
       staticConfig.DIR_SOUNDS = std::string(val_ptr);
     else if ( strcasecmp(name_ptr, "ZM_DIR_EXPORTS") == 0 )
@@ -352,6 +350,14 @@ void Config::Load() {
     exit(-1);
   }
 
+  if (items) {
+    for ( int i = 0; i < n_items; i++ ) {
+      delete items[i];
+      items[i] = nullptr;
+    }
+    delete[] items;
+    items = nullptr;
+  }
   items = new ConfigItem *[n_items];
   for ( int i = 0; MYSQL_ROW dbrow = mysql_fetch_row(result); i++ ) {
     items[i] = new ConfigItem(dbrow[0], dbrow[1], dbrow[2]);
@@ -360,7 +366,7 @@ void Config::Load() {
 }
 
 void Config::Assign() {
-ZM_CFG_ASSIGN_LIST
+  ZM_CFG_ASSIGN_LIST
 }
 
 const ConfigItem &Config::Item(int id) {
@@ -369,18 +375,18 @@ const ConfigItem &Config::Item(int id) {
     Assign();
   }
 
-  if ( id < 0 || id > ZM_MAX_CFG_ID || id > n_items ) {
+  if ( id < 0 || id > ZM_MAX_CFG_ID ) {
     Error("Attempt to access invalid config, id = %d. Try running 'zmupdate.pl -f' to reload config.", id);
     exit(-1);
   }
 
   ConfigItem *item = items[id];
-  
+
   if ( !item ) {
     Error("Can't find config item %d", id);
     exit(-1);
   }
-    
+
   return *item;
 }
 
