@@ -25,9 +25,6 @@
 
 extern "C" {
 #include <libavutil/pixdesc.h>
-#ifdef HAVE_QUADRA
-#include <libavutil/hwcontext_ni_quad.h>
-#endif
 }
 
 /*
@@ -42,48 +39,31 @@ extern "C" {
       */
 
 static CodecData dec_codecs[] = {
-#if HAVE_LIBAVUTIL_HWCONTEXT_H && LIBAVCODEC_VERSION_CHECK(57, 107, 0, 107, 0)
-#ifdef HAVE_QUADRA
-  { AV_CODEC_ID_AV1, "av1", "av1_ni_quadra_dec", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", "xcoder-params='out=hw'" },
-  { AV_CODEC_ID_VP9, "vp9", "vp9_ni_quadra_dec", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", "xcoder-params='out=hw'" },
-  { AV_CODEC_ID_H265, "hevc", "h265_ni_quadra_dec", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", "xcoder-params='out=hw'" },
-  { AV_CODEC_ID_H264, "h264", "h264_ni_quadra_dec", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", "xcoder-params='out=hw'" },
-  { AV_CODEC_ID_MJPEG, "mjpeg", "jpeg_ni_quadra_dec", AV_PIX_FMT_YUVJ420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", "xcoder-params='out=hw'" },
-#endif
-#endif
   { AV_CODEC_ID_AV1, "av1", "libsvtav1", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_AV1, "av1", "libaom-av1", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
-  { AV_CODEC_ID_AV1, "av1", "av1_vaapi", AV_PIX_FMT_YUV420P, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
   { AV_CODEC_ID_MJPEG, "mjpeg", "mjpeg", AV_PIX_FMT_YUVJ422P, AV_PIX_FMT_YUVJ422P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H264, "h264", "h264", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H264, "h264", "h264_v4l2m2m", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
-  { AV_CODEC_ID_H264, "h264", "h264_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
-
   { AV_CODEC_ID_H265, "hevc", "hevc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H265, "hevc", "hevc_v4l2m2m", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
-  { AV_CODEC_ID_H265, "hevc", "hevc_vaapi", AV_PIX_FMT_NV12, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
-  { AV_CODEC_ID_H265, "hevc", "hevc_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
   { AV_CODEC_ID_H265, "hevc", "hevc_cuvid", AV_PIX_FMT_NV12, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H265, "hevc", "libx265", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
+#if HAVE_LIBAVUTIL_HWCONTEXT_H && LIBAVCODEC_VERSION_CHECK(57, 107, 0, 107, 0)
+  { AV_CODEC_ID_H264, "h264", "h264_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
+  { AV_CODEC_ID_AV1, "av1", "av1_vaapi", AV_PIX_FMT_YUV420P, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
+  { AV_CODEC_ID_H265, "hevc", "hevc_vaapi", AV_PIX_FMT_NV12, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
+  { AV_CODEC_ID_H265, "hevc", "hevc_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
+#endif
 };
 
 static CodecData enc_codecs[] = {
 #if HAVE_LIBAVUTIL_HWCONTEXT_H && LIBAVCODEC_VERSION_CHECK(57, 107, 0, 107, 0)
-#ifdef HAVE_QUADRA
-  { AV_CODEC_ID_AV1, "av1", "av1_ni_quadra_enc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
-  { AV_CODEC_ID_H265, "hevc", "h265_ni_quadra_enc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
-  { AV_CODEC_ID_H265, "hevc", "h265_ni_quadra_enc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
-  { AV_CODEC_ID_H264, "h264", "h264_ni_quadra_enc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
-  { AV_CODEC_ID_MJPEG, "mjpeg", "jpeg_ni_quadra_enc", AV_PIX_FMT_YUVJ420P, AV_PIX_FMT_NI_QUAD, AV_HWDEVICE_TYPE_NI_QUADRA, "-1", nullptr },
-#endif
-  { AV_CODEC_ID_H265, "hevc", "hevc_vaapi", AV_PIX_FMT_YUV420P, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
+  { AV_CODEC_ID_H265, "hevc", "hevc_vaapi", AV_PIX_FMT_NV12, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
   { AV_CODEC_ID_H265, "hevc", "hevc_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
-  { AV_CODEC_ID_H265, "hevc", "hevc_nvenc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
-  { AV_CODEC_ID_H265, "hevc", "libx265", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
-
-  { AV_CODEC_ID_H264, "h264", "h264_vaapi", AV_PIX_FMT_YUV420P, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
+  { AV_CODEC_ID_H265, "hevc", "hevc_nvenc", AV_PIX_FMT_NV12, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
+  { AV_CODEC_ID_H264, "h264", "h264_vaapi", AV_PIX_FMT_NV12, AV_PIX_FMT_VAAPI, AV_HWDEVICE_TYPE_VAAPI, nullptr, nullptr },
   { AV_CODEC_ID_H264, "h264", "h264_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
-  { AV_CODEC_ID_H264, "h264", "h264_nvenc", AV_PIX_FMT_YUV420P, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
+  { AV_CODEC_ID_H264, "h264", "h264_nvenc", AV_PIX_FMT_NV12, AV_PIX_FMT_NV12, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H264, "h264", "h264_omx", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P,  AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_H264, "h264", "h264_v4l2m2m", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P,  AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
   { AV_CODEC_ID_AV1, "av1", "av1_qsv", AV_PIX_FMT_YUV420P, AV_PIX_FMT_QSV, AV_HWDEVICE_TYPE_QSV, nullptr, nullptr },
@@ -98,18 +78,6 @@ static CodecData enc_codecs[] = {
   { AV_CODEC_ID_AV1, "av1", "libaom-av1", AV_PIX_FMT_YUV420P, AV_PIX_FMT_YUV420P, AV_HWDEVICE_TYPE_NONE, nullptr, nullptr },
 };
 
-#ifdef HAVE_QUADRA
-int ni_get_cardno(const AVCodecContext *ctx) {
-  if (ctx->hw_frames_ctx) {
-    AVNIFramesContext* ni_hwf_ctx = (AVNIFramesContext*)((AVHWFramesContext*)ctx->hw_frames_ctx->data)->hwctx;
-    if (ni_hwf_ctx) {
-      return ni_hwf_ctx->hw_id;
-    }
-  }
-  return -1;
-}
-#endif
-
 std::list<const CodecData*> get_encoder_data(const std::string &wanted_codec, const std::string &wanted_encoder) {
   std::list<const CodecData*> results;
 
@@ -119,23 +87,16 @@ std::list<const CodecData*> get_encoder_data(const std::string &wanted_codec, co
       if (wanted_encoder != enc_codecs[i].codec_name) {
         Debug(1, "Not the right codec name %s != %s", enc_codecs[i].codec_name, wanted_encoder.c_str());
         continue;
-      } else {
-        Debug(1, "Have the right codec name %s != %s", enc_codecs[i].codec_name, wanted_encoder.c_str());
       }
     }
-    if ((!wanted_codec.empty() and (wanted_codec != "auto")) and (enc_codecs[i].codec_codec != wanted_codec)) {
-      Debug(1, "Not the right codec id %s != %s for %s",
+
+    if ((!wanted_codec.empty() and wanted_codec != "auto") and (enc_codecs[i].codec_codec != wanted_codec)) {
+      Debug(4, "Not the right codec id %s != %s for %s",
           chosen_codec_data->codec_codec,
           wanted_codec.c_str(),
           chosen_codec_data->codec_name
           );
       continue;
-    } else {
-      Debug(1, "Have the right codec id %s != %s for %s",
-          chosen_codec_data->codec_codec,
-          wanted_codec.c_str(),
-          chosen_codec_data->codec_name
-	  );
     }
     const AVCodec *codec = avcodec_find_encoder_by_name(chosen_codec_data->codec_name);
     if (!codec) {
@@ -152,7 +113,6 @@ std::list<const CodecData*> get_decoder_data(int wanted_codec, const std::string
 
   for (unsigned int i = 0; i < sizeof(dec_codecs) / sizeof(*dec_codecs); i++) {
     const CodecData *chosen_codec_data = &dec_codecs[i];
-    Debug(1, "Looking at codec %s for %d, want %s %d", chosen_codec_data->codec_name, chosen_codec_data->codec_id, wanted_decoder.c_str(), wanted_codec);
     if (!wanted_decoder.empty() and wanted_decoder != "auto") {
       if (wanted_decoder != chosen_codec_data->codec_name) {
         Debug(1, "Not the right codec name %s != %s", chosen_codec_data->codec_name, wanted_decoder.c_str());
@@ -174,10 +134,8 @@ std::list<const CodecData*> get_decoder_data(int wanted_codec, const std::string
       Debug(1, "Didn't find codec for %s", chosen_codec_data->codec_name);
       continue;
     }
-    Debug(1, "Found codec %s for %d", chosen_codec_data->codec_name, chosen_codec_data->codec_id);
     results.push_back(chosen_codec_data);
   }
-  Debug(1, "Results size %zu", results.size());
   return results;
 }
 
@@ -428,29 +386,21 @@ simple_round:
 }
 #endif
 
-const std::string get_fps_string(double d, const char *postfix) {
+static void zm_log_fps(double d, const char *postfix) {
   uint64_t v = lrintf(d * 100);
   if (!v) {
-    return stringtf("%1.4f %s", d, postfix);
+    Debug(1, "%1.4f %s", d, postfix);
   } else if (v % 100) {
-    return stringtf("%3.2f %s", d, postfix);
+    Debug(1, "%3.2f %s", d, postfix);
   } else if (v % (100 * 1000)) {
-    return stringtf("%1.0f %s", d, postfix);
+    Debug(1, "%1.0f %s", d, postfix);
   } else {
-    return stringtf("%1.0fk %s", d / 1000, postfix);
+    Debug(1, "%1.0fk %s", d / 1000, postfix);
   }
 }
 
-void zm_log_fps(double d, const char *postfix) {
-  Debug(1, "%s", get_fps_string(d, postfix).c_str());
-}
-
 void zm_dump_codecpar(const AVCodecParameters *par) {
-  Debug(1, "Dumping codecpar %s", get_codecpar_string(par).c_str());
-}
-
-const std::string get_codecpar_string(const AVCodecParameters *par) {
-  return stringtf("codec_type %d %s codec_id %d %s codec_tag %" PRIu32
+  Debug(1, "Dumping codecpar codec_type %d %s codec_id %d %s codec_tag %" PRIu32
         " width %d height %d bit_rate%" PRIu64 " bpcs %d bprs %d format%d %s"
         " extradata:%d:%s profile %d level %d field order %d color_range %d"
         " color_primaries %d color_trc %d color_space %d location %d video_delay %d",
@@ -529,16 +479,18 @@ void zm_dump_stream_format(AVFormatContext *ic, int i, int index, int is_output)
   if (flags & AVFMT_SHOW_IDS)
     Debug(1, "ids [0x%x]", st->id);
   Debug(1, "    Stream #%d:%d", index, i);
-  Debug(1, "global bitrate %" PRId64, ic->bit_rate);
   zm_dump_stream(st);
 }
-
 void zm_dump_stream(AVStream *st) {
+  AVDictionaryEntry *lang = av_dict_get(st->metadata, "language", nullptr, 0);
   AVCodecParameters *codec = st->codecpar;
-  std::string output;
 
-  output += stringtf("frame_size:%d timebase: %d/%d", codec->frame_size, st->time_base.num, st->time_base.den);
-  output += stringtf(" codec: %s %s", avcodec_get_name(st->codecpar->codec_id), av_get_media_type_string(st->codecpar->codec_type));
+  /* the pid is an important information, so we display it */
+  /* XXX: add a generic system */
+  if (lang)
+    Debug(1, "language (%s)", lang->value);
+  Debug(1, "frame_size:%d stream timebase: %d/%d", codec->frame_size, st->time_base.num, st->time_base.den);
+  Debug(1, "codec: %s %s", avcodec_get_name(st->codecpar->codec_id), av_get_media_type_string(st->codecpar->codec_type));
 
   if (st->sample_aspect_ratio.num && // default
       av_cmp_q(st->sample_aspect_ratio, codec->sample_aspect_ratio)
@@ -549,11 +501,11 @@ void zm_dump_stream(AVStream *st) {
               codec->width  * (int64_t)st->sample_aspect_ratio.num,
               codec->height * (int64_t)st->sample_aspect_ratio.den,
               1024 * 1024);
-    output += stringtf(" SAR %d:%d DAR %d:%d",
+    Debug(1, ", SAR %d:%d DAR %d:%d",
           st->sample_aspect_ratio.num, st->sample_aspect_ratio.den,
           display_aspect_ratio.num, display_aspect_ratio.den);
   } else {
-    output += stringtf(" SAR %d:%d ",
+    Debug(1, ", SAR %d:%d ",
           st->sample_aspect_ratio.num, st->sample_aspect_ratio.den);
   }
 
@@ -562,45 +514,45 @@ void zm_dump_stream(AVStream *st) {
     int tbn = st->time_base.den && st->time_base.num;
 
     if (fps)
-      output += get_fps_string(av_q2d(st->avg_frame_rate), "fps");
+      zm_log_fps(av_q2d(st->avg_frame_rate), "fps");
     if (tbn)
-      output += get_fps_string(1 / av_q2d(st->time_base), "stream tb numerator");
-
-    output += get_codecpar_string(codec);
+      zm_log_fps(1 / av_q2d(st->time_base), "stream tb numerator");
   } else if (codec->codec_type == AVMEDIA_TYPE_AUDIO) {
 #if LIBAVUTIL_VERSION_CHECK(57, 28, 100, 28, 0)
-    output += stringtf("profile %d channels %d sample_rate %d",
+    Debug(1, "profile %d channels %d sample_rate %d",
           codec->profile, codec->ch_layout.nb_channels, codec->sample_rate);
 #else
-    output += stringtf("profile %d channels %d sample_rate %d",
+    Debug(1, "profile %d channels %d sample_rate %d",
           codec->profile, codec->channels, codec->sample_rate);
 #endif
   } else {
-    output += stringtf("Unknown codec type %d", codec->codec_type);
+    Debug(1, "Unknown codec type %d", codec->codec_type);
   }
 
   if (st->disposition & AV_DISPOSITION_DEFAULT)
-    output += " (default)";
+    Debug(1, " (default)");
   if (st->disposition & AV_DISPOSITION_DUB)
-    output += " (dub)";
+    Debug(1, " (dub)");
   if (st->disposition & AV_DISPOSITION_ORIGINAL)
-    output += " (original)";
+    Debug(1, " (original)");
   if (st->disposition & AV_DISPOSITION_COMMENT)
-    output += " (comment)";
+    Debug(1, " (comment)");
   if (st->disposition & AV_DISPOSITION_LYRICS)
-    output += " (lyrics)";
+    Debug(1, " (lyrics)");
   if (st->disposition & AV_DISPOSITION_KARAOKE)
-    output += " (karaoke)";
+    Debug(1, " (karaoke)");
   if (st->disposition & AV_DISPOSITION_FORCED)
-    output += " (forced)";
+    Debug(1, " (forced)");
   if (st->disposition & AV_DISPOSITION_HEARING_IMPAIRED)
-    output += " (hearing impaired)";
+    Debug(1, " (hearing impaired)");
   if (st->disposition & AV_DISPOSITION_VISUAL_IMPAIRED)
-    output += " (visual impaired)";
+    Debug(1, " (visual impaired)");
   if (st->disposition & AV_DISPOSITION_CLEAN_EFFECTS)
-    output += " (clean effects)";
+    Debug(1, " (clean effects)");
 
-  Debug(1, "%s", output.c_str());
+  //dump_metadata(NULL, st->metadata, "    ");
+
+  //dump_sidedata(NULL, st, "    ");
 }
 
 int check_sample_fmt(const AVCodec *codec, enum AVSampleFormat sample_fmt) {
@@ -798,15 +750,3 @@ int zm_get_samples_from_fifo(AVAudioFifo *fifo, AVFrame *frame) {
   zm_dump_frame(frame, "Out frame after fifo read");
   return 1;
 }
-#include <algorithm> // for std::max and std::min
-
-// Converts libjpeg quality [0-100] to ffmpeg -q:v [2-31] for MJPEG encoding
-int libjpeg_to_ffmpeg_qv(int libjpeg_quality) {
-    // Clamp libjpeg_quality to valid range
-    libjpeg_quality = std::max(0, std::min(100, libjpeg_quality));
-    // Map libjpeg 0-100 to ffmpeg 31-2
-    int ffmpeg_qv = 31 - static_cast<int>(libjpeg_quality * 29.0 / 100.0 + 0.5);
-    // Clamp ffmpeg_qv to valid range
-    ffmpeg_qv = std::max(2, std::min(31, ffmpeg_qv));
-    return ffmpeg_qv;
-}
