@@ -21,20 +21,19 @@
 
 #include "zm_packet.h"
 #include <sys/stat.h>
-#include <unistd.h>
 
 FileCamera::FileCamera(
-    const Monitor *monitor,
-    const char *p_path,
-    int p_width,
-    int p_height,
-    int p_colours,
-    int p_brightness,
-    int p_contrast,
-    int p_hue,
-    int p_colour,
-    bool p_capture,
-    bool p_record_audio)
+  const Monitor *monitor,
+  const char *p_path,
+  int p_width,
+  int p_height,
+  int p_colours,
+  int p_brightness,
+  int p_contrast,
+  int p_hue,
+  int p_colour,
+  bool p_capture,
+  bool p_record_audio)
   : Camera(
       monitor,
       FILE_SRC,
@@ -47,22 +46,21 @@ FileCamera::FileCamera(
       p_hue,
       p_colour,
       p_capture,
-      p_record_audio)
-{
-  strncpy( path, p_path, sizeof(path)-1 );
-  if ( capture ) {
+      p_record_audio),
+    path(p_path) {
+  if (capture) {
     Initialise();
   }
 }
 
 FileCamera::~FileCamera() {
-  if ( capture ) {
+  if (capture) {
     Terminate();
   }
 }
 
 void FileCamera::Initialise() {
-  if ( !path[0] ) {
+  if (path.empty()) {
     Fatal("No path specified for file image");
   }
 }
@@ -70,10 +68,16 @@ void FileCamera::Initialise() {
 void FileCamera::Terminate() {
 }
 
+int FileCamera::PrimeCapture() {
+  getVideoStream();
+  Info("Priming capture from %s", path.c_str());
+  return 1;
+}
+
 int FileCamera::PreCapture() {
-  struct stat statbuf;
-  if ( stat(path, &statbuf) < 0 ) {
-    Error("Can't stat %s: %s", path, strerror(errno));
+  struct stat statbuf = {};
+  if (stat(path.c_str(), &statbuf) < 0) {
+    Error("Can't stat %s: %s", path.c_str(), strerror(errno));
     return -1;
   }
   bytes += statbuf.st_size;
@@ -81,13 +85,20 @@ int FileCamera::PreCapture() {
   // This waits until 1 second has passed since it was modified. Effectively limiting fps to 60.
   // Which is kinda bogus. If we were writing to this jpg constantly faster than we are monitoring it here
   // we would never break out of this loop
-  while ( (time(nullptr) - statbuf.st_mtime) < 1 ) {
-    usleep(100000);
-  }
+//while ((time(nullptr) - statbuf.st_mtime) < 1) {
+    //std::this_thread::sleep_for(Milliseconds(100));
+  //}
   return 0;
 }
 
 int FileCamera::Capture(std::shared_ptr<ZMPacket> &zm_packet) {
+  if (!zm_packet->image) {
+    zm_packet->image = new Image(width, height, colours, subpixelorder);
+  }
+  zm_packet->keyframe = 1;
+  zm_packet->codec_type = AVMEDIA_TYPE_VIDEO;
+  zm_packet->packet->stream_index = mVideoStreamId;
+  zm_packet->stream = mVideoStream;
   return zm_packet->image->ReadJpeg(path, colours, subpixelorder) ? 1 : -1;
 }
 
