@@ -18,6 +18,7 @@
 //
 
 #include "zm_monitor.h"
+#include "zm_signal.h"
 
 #include <cstring>
 #include <sstream>
@@ -118,9 +119,9 @@ void Monitor::ONVIF::start() {
         std::ostream *old_stream = soap->os;
         soap->os = &ss; // assign a stringstream to write output to
         proxyEvent.CreatePullPointSubscription(&request, response);
-        soap_write__tev__CreatePullPointSubscriptionResponse(soap, &response);
+        //soap_write__tev__CreatePullPointSubscriptionResponse(soap, &response);
         soap->os = old_stream; // no longer writing to the stream
-        Debug(1, "Response was %s", ss.str().c_str());
+        Error("Response was %s", ss.str().c_str());
 
         _wsnt__Unsubscribe wsnt__Unsubscribe;
         _wsnt__UnsubscribeResponse wsnt__UnsubscribeResponse;
@@ -222,7 +223,7 @@ void Monitor::ONVIF::WaitForMessage() {
         soap->os = old_stream; // no longer writing to the stream
         Debug(1, "Response was %s", ss.str().c_str());
 
-        // healthy = false;
+        healthy = false;
       } else {
         // EOF
         std::unique_lock<std::mutex> lck(alarms_mutex);
@@ -299,6 +300,8 @@ void Monitor::ONVIF::WaitForMessage() {
         }  // end foreach msg
       } // end scope for lock
 
+      if (zm_terminate) return;
+
       // we renew the current subscription .........
       if (parent->soap_wsa_compl) {
         set_credentials(soap);
