@@ -1,21 +1,21 @@
 //
 // ZoneMinder Remote Camera Class Implementation, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
-// 
+//
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-// 
+//
 
 #include "zm_remote_camera_rtsp.h"
 
@@ -24,33 +24,35 @@
 #include "zm_packet.h"
 #include "zm_signal.h"
 
-#if HAVE_LIBAVFORMAT
-
 RemoteCameraRtsp::RemoteCameraRtsp(
-    const Monitor *monitor,
-    const std::string &p_method,
-    const std::string &p_host,
-    const std::string &p_port,
-    const std::string &p_path,
-    int p_width,
-    int p_height,
-    bool p_rtsp_describe,
-    int p_colours,
-    int p_brightness,
-    int p_contrast,
-    int p_hue,
-    int p_colour,
-    bool p_capture,
-    bool p_record_audio ) :
+  const Monitor *monitor,
+  const std::string &p_method,
+  const std::string &p_host,
+  const std::string &p_port,
+  const std::string &p_path,
+  const std::string &p_user,
+  const std::string &p_pass,
+  int p_width,
+  int p_height,
+  bool p_rtsp_describe,
+  int p_colours,
+  int p_brightness,
+  int p_contrast,
+  int p_hue,
+  int p_colour,
+  bool p_capture,
+  bool p_record_audio ) :
   RemoteCamera(
-      monitor, "rtsp",
-      p_host, p_port, p_path,
-      p_width, p_height, p_colours,
-      p_brightness, p_contrast, p_hue, p_colour,
-      p_capture, p_record_audio),
+    monitor, "rtsp",
+    p_host, p_port, p_path,
+    p_user, p_pass,
+    p_width, p_height, p_colours,
+    p_brightness, p_contrast, p_hue, p_colour,
+    p_capture, p_record_audio),
   rtsp_describe(p_rtsp_describe),
-  frameCount(0)
-{
+  user(p_user),
+  pass(p_pass),
+  frameCount(0) {
   if ( p_method == "rtpUni" )
     method = RtspThread::RTP_UNICAST;
   else if ( p_method == "rtpMulti" )
@@ -65,7 +67,7 @@ RemoteCameraRtsp::RemoteCameraRtsp(
   if ( capture ) {
     Initialise();
   }
-  
+
   /* Has to be located inside the constructor so other components such as zma will receive correct colours and subpixel order */
   if ( colours == ZM_COLOUR_RGB32 ) {
     subpixelorder = ZM_SUBPIX_ORDER_RGBA;
@@ -84,8 +86,8 @@ RemoteCameraRtsp::RemoteCameraRtsp(
 RemoteCameraRtsp::~RemoteCameraRtsp() {
 
   if ( mVideoCodecContext ) {
-     avcodec_close(mVideoCodecContext);
-     mVideoCodecContext = nullptr; // Freed by avformat_free_context in the destructor of RtspThread class
+    avcodec_free_context(&mVideoCodecContext);
+    mVideoCodecContext = nullptr; // Freed by avformat_free_context in the destructor of RtspThread class
   }
   // Is allocated in RTSPThread and is free there as well
   mFormatContext = nullptr;
@@ -112,7 +114,7 @@ void RemoteCameraRtsp::Terminate() {
 }
 
 int RemoteCameraRtsp::Connect() {
-  rtspThread = ZM::make_unique<RtspThread>(monitor->Id(), method, protocol, host, port, path, auth, rtsp_describe);
+  rtspThread = zm::make_unique<RtspThread>(monitor->Id(), method, protocol, host, port, path, user, pass, rtsp_describe);
 
   return 0;
 }
@@ -131,9 +133,10 @@ int RemoteCameraRtsp::PrimeCapture() {
 
   Debug(2, "Waiting for sources");
   for (int i = 100; i && !zm_terminate && !rtspThread->hasSources(); i--) {
-    usleep(100000);
+    std::this_thread::sleep_for(Microseconds(10000));
   }
-  if ( !rtspThread->hasSources() ) {
+
+  if (!rtspThread->hasSources()) {
     Error("No RTSP sources");
     return -1;
   }
@@ -146,7 +149,7 @@ int RemoteCameraRtsp::PrimeCapture() {
   mVideoStreamId = -1;
   mAudioStreamId = -1;
 
-  // Find the first video stream. 
+  // Find the first video stream.
   for ( unsigned int i = 0; i < mFormatContext->nb_streams; i++ ) {
     if ( is_video_stream(mFormatContext->streams[i]) ) {
       if ( mVideoStreamId == -1 ) {
@@ -179,12 +182,8 @@ int RemoteCameraRtsp::PrimeCapture() {
     Debug(3, "Unable to locate audio stream");
 
   // Get a pointer to the codec context for the video stream
-#if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
-  mVideoCodecContext = avcodec_alloc_context3(NULL);
+  mVideoCodecContext = avcodec_alloc_context3(nullptr);
   avcodec_parameters_to_context(mVideoCodecContext, mFormatContext->streams[mVideoStreamId]->codecpar);
-#else
-  mVideoCodecContext = mFormatContext->streams[mVideoStreamId]->codec;
-#endif
 
   // Find the decoder for the video stream
   const AVCodec *codec = avcodec_find_decoder(mVideoCodecContext->codec_id);
@@ -194,21 +193,12 @@ int RemoteCameraRtsp::PrimeCapture() {
   }
 
   // Open codec
-#if !LIBAVFORMAT_VERSION_CHECK(53, 8, 0, 8, 0)
-  if ( avcodec_open(mVideoCodecContext, codec) < 0 )
-#else
-  if ( avcodec_open2(mVideoCodecContext, codec, nullptr) < 0 )
-#endif
-  {
+  if ( avcodec_open2(mVideoCodecContext, codec, nullptr) < 0 ) {
     Error("Can't open codec");
     return -1;
   }
 
-#if LIBAVUTIL_VERSION_CHECK(54, 6, 0, 6, 0)
   int pSize = av_image_get_buffer_size(imagePixFormat, width, height, 1);
-#else
-  int pSize = avpicture_get_size(imagePixFormat, width, height);
-#endif
 
   if ( (unsigned int)pSize != imagesize ) {
     Error("Image size mismatch. Required: %d Available: %llu", pSize, imagesize);
@@ -247,20 +237,20 @@ int RemoteCameraRtsp::Capture(std::shared_ptr<ZMPacket> &zm_packet) {
       if ( mVideoCodecContext->codec_id == AV_CODEC_ID_H264 ) {
         // SPS and PPS frames should be saved and appended to IDR frames
         int nalType = (buffer.head()[3] & 0x1f);
-        
+
         // SPS The SPS NAL unit contains parameters that apply to a series of consecutive coded video pictures
         if ( nalType == 1 ) {
         } else if ( nalType == 7 ) {
           lastSps = buffer;
           continue;
         } else if ( nalType == 8 ) {
-        // PPS The PPS NAL unit contains parameters that apply to the decoding of one or more individual pictures inside a coded video sequence
+          // PPS The PPS NAL unit contains parameters that apply to the decoding of one or more individual pictures inside a coded video sequence
           lastPps = buffer;
           continue;
         } else if ( nalType == 5 ) {
           packet->flags |= AV_PKT_FLAG_KEY;
           zm_packet->keyframe = 1;
-        // IDR
+          // IDR
           buffer += lastSps;
           buffer += lastPps;
         } else {
@@ -296,4 +286,3 @@ int RemoteCameraRtsp::Capture(std::shared_ptr<ZMPacket> &zm_packet) {
 int RemoteCameraRtsp::PostCapture() {
   return 1;
 }
-#endif // HAVE_LIBAVFORMAT
