@@ -26,7 +26,7 @@
 #define TRACE_SIZE 16
 
 bool zm_reload = false;
-std::atomic<bool> zm_terminate = false;
+bool zm_terminate = false;
 bool zm_panic = false;
 
 RETSIGTYPE zm_hup_handler(int signal) {
@@ -95,7 +95,8 @@ RETSIGTYPE zm_die_handler(int signal)
   // Print backtrace if enabled and available
 #if ( !defined(ZM_NO_CRASHTRACE) && HAVE_DECL_BACKTRACE && HAVE_DECL_BACKTRACE_SYMBOLS )
   void *trace[TRACE_SIZE];
-  int trace_size = backtrace(trace, TRACE_SIZE);
+  int trace_size = 0;
+  trace_size = backtrace(trace, TRACE_SIZE);
 
   char cmd[1024] = "addr2line -Cfip -e ";
   char *cmd_ptr = cmd + strlen(cmd);
