@@ -1,27 +1,28 @@
 /*
  * ZoneMinder Signal Handling Interface, $Date$, $Revision$
  * Copyright (C) 2001-2008 Philip Coombes
- * 
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/  
+*/
 
 #ifndef ZM_SIGNAL_H
 #define ZM_SIGNAL_H
 
 #include "zm_config.h"
 #include <csignal>
+#include <atomic>
 
 #if HAVE_EXECINFO_H
 #include <execinfo.h>
@@ -33,7 +34,7 @@
 typedef RETSIGTYPE (SigHandler)( int );
 
 extern bool zm_reload;
-extern bool zm_terminate;
+extern std::atomic<bool> zm_terminate;
 
 RETSIGTYPE zmc_hup_handler( int signal );
 RETSIGTYPE zmc_term_handler( int signal );
