@@ -1,21 +1,21 @@
 //
 // ZoneMinder Stream Interfaces, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
-// 
+//
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-// 
+//
 
 #ifndef ZM_STREAM_H
 #define ZM_STREAM_H
@@ -23,17 +23,17 @@
 #include "zm_box.h"
 #include "zm_logger.h"
 #include "zm_mpeg.h"
+#include "zm_time.h"
 #include <memory>
 #include <sys/un.h>
 
 class Image;
 class Monitor;
 
-#define TV_2_FLOAT( tv ) ( double((tv).tv_sec) + (double((tv).tv_usec) / 1000000.0) )
 #define BOUNDARY "ZoneMinderFrame"
 
 class StreamBase {
-public:
+ public:
   typedef enum {
     STREAM_JPEG,
     STREAM_RAW,
@@ -41,10 +41,11 @@ public:
     STREAM_SINGLE,
     STREAM_MPEG
   } StreamType;
+  typedef enum { FRAME_NORMAL, FRAME_ANALYSIS } FrameType;
 
-protected:
-  static const int MAX_STREAM_DELAY = 5; // Seconds
-  static const int MAX_SLEEP_USEC = 500000; // .5 Seconds
+ protected:
+  static constexpr Seconds MAX_STREAM_DELAY = Seconds(5);
+  static constexpr Milliseconds MAX_SLEEP = Milliseconds(100);
 
   static const StreamType DEFAULT_TYPE = STREAM_JPEG;
   enum { DEFAULT_RATE=ZM_RATE_BASE };
@@ -53,7 +54,7 @@ protected:
   enum { DEFAULT_MAXFPS=10 };
   enum { DEFAULT_BITRATE=100000 };
 
-protected:
+ protected:
   typedef struct {
     int msg_type;
     char msg_data[16];
@@ -89,14 +90,19 @@ protected:
     CMD_VARPLAY,
     CMD_GET_IMAGE,
     CMD_QUIT,
+    CMD_MAXFPS,
+    CMD_ANALYZE_ON,
+    CMD_ANALYZE_OFF,
+    CMD_ZOOMSTOP,
     CMD_QUERY=99
   } MsgCommand;
 
-protected:
+ protected:
   int monitor_id;
   std::shared_ptr<Monitor> monitor;
 
   StreamType type;
+  FrameType   frame_type;
   const char *format;
   int replay_rate;
   int scale;
@@ -119,45 +125,55 @@ protected:
   int lock_fd;
   bool paused;
   int step;
+  bool send_twice;        // flag to send the same frame twice
 
-  struct timeval now;
-  struct timeval last_comm_update;
+  TimePoint now;
+  TimePoint last_comm_update;
 
   double maxfps;
   double base_fps;        // Should be capturing fps, hence a rough target
   double effective_fps;   // Target fps after taking max_fps into account
   double actual_fps;      // sliding calculated actual streaming fps achieved
-  struct timeval last_fps_update;
+  TimePoint last_fps_update;
   int frame_count;      // Count of frames sent
   int last_frame_count; // Used in calculating actual_fps from frame_count - last_frame_count
 
   int frame_mod;
+  int frames_to_send;
 
-  double last_frame_sent;
-  struct timeval last_frame_timestamp;
+  TimePoint last_frame_sent;
+  SystemTimePoint last_frame_timestamp;
+  TimePoint when_to_send_next_frame;  // When to send next frame so if now < send_next_frame, skip
 
-#if HAVE_LIBAVCODEC   
   VideoStream *vid_stream;
-#endif // HAVE_LIBAVCODEC   
 
   CmdMsg msg;
+  bool got_command = false; // commands like zoom should output a frame even if paused
 
-  unsigned char *temp_img_buffer;     // Used when encoding or sending file data
+  uint8_t *temp_img_buffer;     // Used when encoding or sending file data
   size_t temp_img_buffer_size;
 
-protected:
+  AVPixelFormat  mJpegPixelFormat; // Not what the codec context is configured to use, but what the mjpegswscontext is configured as input
+  AVCodecContext *mJpegCodecContext;
+  SwsContext     *mJpegSwsContext;
+  int bytes_sent;
+
+ protected:
   bool loadMonitor(int monitor_id);
   bool checkInitialised();
   void updateFrameRate(double fps);
   Image *prepareImage(Image *image);
-  bool checkCommandQueue();
+  void checkCommandQueue();
   virtual void processCommand(const CmdMsg *msg)=0;
+  void reserveTempImgBuffer(size_t size);
+  bool initContexts(int in_width, int in_height, AVPixelFormat p_format, int out_width, int out_height, unsigned int quality);
 
-public:
-  StreamBase(): 
+ public:
+  StreamBase():
     monitor_id(0),
     monitor(nullptr),
     type(DEFAULT_TYPE),
+    frame_type(FRAME_NORMAL),
     format(""),
     replay_rate(DEFAULT_RATE),
     scale(DEFAULT_SCALE),
@@ -180,24 +196,25 @@ public:
     base_fps(0.0),
     effective_fps(0.0),
     actual_fps(0.0),
-    last_fps_update({}),
     frame_count(0),
     last_frame_count(0),
     frame_mod(1),
+    frames_to_send(-1),
+    got_command(false),
     temp_img_buffer(nullptr),
-    temp_img_buffer_size(0)
+    temp_img_buffer_size(0),
+    mJpegCodecContext(nullptr),
+    mJpegSwsContext(nullptr),
+    bytes_sent(0)
   {
     memset(&loc_sock_path, 0, sizeof(loc_sock_path));
     memset(&loc_addr, 0, sizeof(loc_addr));
     memset(&rem_sock_path, 0, sizeof(rem_sock_path));
     memset(&rem_addr, 0, sizeof(rem_addr));
     memset(&sock_path_lock, 0, sizeof(sock_path_lock));
+    last_fps_update = std::chrono::steady_clock::now();
 
-#if HAVE_LIBAVCODEC   
     vid_stream = nullptr;
-#endif // HAVE_LIBAVCODEC   
-    last_frame_sent = 0.0;
-    last_frame_timestamp = {};
     msg = { 0, { 0 } };
   }
   virtual ~StreamBase();
@@ -210,7 +227,9 @@ public:
       type = STREAM_RAW;
     }
 #endif
-
+  }
+  void setStreamFrameType(FrameType p_type) {
+    frame_type = p_type;
   }
   void setStreamFormat(const char *p_format) {
     format = p_format;
@@ -221,10 +240,11 @@ public:
       scale = DEFAULT_SCALE;
   }
   void setStreamReplayRate(int p_rate) {
-    Debug(2, "Setting replay_rate %d", p_rate);
+    Debug(1, "Setting replay_rate %d", p_rate);
     replay_rate = p_rate;
   }
   void setStreamMaxFPS(double p_maxfps) {
+    Debug(1, "Setting max fps to %f", p_maxfps);
     maxfps = p_maxfps;
   }
   void setStreamBitrate(int p_bitrate) {
@@ -233,6 +253,7 @@ public:
   void setStreamQueue(int p_connkey) {
     connkey = p_connkey;
   }
+  void setFramesToSend(int p_frames_to_send) { frames_to_send = p_frames_to_send; }
   bool sendTextFrame(const char *text);
   virtual void openComms();
   virtual void closeComms();
