@@ -29,6 +29,7 @@
 #include <regex>
 #include <sstream>
 #include <sys/stat.h>
+#include <sched.h>
 
 #if defined(__arm__)
 #include <sys/auxv.h>
@@ -36,6 +37,28 @@
 
 unsigned int sse_version = 0;
 unsigned int neonversion = 0;
+unsigned int our_cpu = 0;
+
+
+unsigned int getcpu() {
+  our_cpu = sched_getcpu();
+  Debug(1, "Our CPU is %u", our_cpu);
+  return our_cpu;
+}
+
+bool set_cpu_affinity(std::thread &thread) {
+  // Create a cpu_set_t object representing a set of CPUs. Clear it and mark only our CPU.
+  cpu_set_t cpuset;
+  CPU_ZERO(&cpuset);
+  CPU_SET(our_cpu, &cpuset);
+  Debug(1, "Setting pthread cpu affinity to %u", our_cpu);
+  int rc = pthread_setaffinity_np(thread.native_handle(), sizeof(cpu_set_t), &cpuset);
+  if (rc != 0) {
+    Error("Error calling pthread_setaffinity_np: %d", rc);
+    return false;
+  }
+  return true;
+}
 
 // Trim Both leading and trailing sets
 std::string Trim(const std::string &str, const std::string &char_set) {
@@ -522,6 +545,59 @@ std::string remove_authentication(const std::string &url) {
   return result;
 }
 
+nlohmann::json scale_coordinates(nlohmann::json coco_object, float width_factor, float height_factor, int width, int height) {
+  nlohmann::json results = nlohmann::json::array();
+  try {
+    Debug(1, "CURL detections %s scaling by %f %f", coco_object.dump().c_str(), width_factor, height_factor);
+    if (coco_object.size() > 0) {
+      Debug(1, "size: %zu", coco_object.size());
+      for (auto it = coco_object.begin(); it != coco_object.end(); ++it) {
+        nlohmann::json detection = *it;
+        Debug(1, "CURL detections detection %s", detection.dump().c_str());
+        if (detection == nullptr) {
+          Debug(1, "No detection!");
+          continue;
+        }
+        nlohmann::json bbox = detection["box"];
+        if (bbox == nullptr) {
+          Debug(1, "No box!");
+          continue;
+        } else {
+          Debug(1, "CURL detections bbox %s", bbox.dump().c_str());
+        }
+        if (bbox.size() > 0) {
+          bbox = bbox[0];
+        }
+
+        float x1 = bbox[0];
+        float y1 = bbox[1];
+        float x2 = bbox[2];
+        float y2 = bbox[3];
+        x1 *= width_factor;
+        y1 *= height_factor;
+        x2 *= width_factor;
+        y2 *= height_factor;
+        if (x1 > width) x1 = width;
+        if (y1 > height) y1 = height;
+        if (x2 > width) x2 = width;
+        if (y2 > height) y2 = height;
+        
+
+        std::array<int, 4> new_bbox = {static_cast<int>(x1),
+         static_cast<int>(y1),
+         static_cast<int>(x2),
+         static_cast<int>(y2)
+        };
+        results.push_back({{"class", detection["class"]}, {"box", new_bbox}, {"confidence", detection["confidence"]}});
+      }
+    }
+  } catch (std::exception const & ex) {
+    Error("scale_coordinates Exception: %s", ex.what());
+  }
+  Debug(1, "CURL detections %s", results.dump().c_str());
+  return results;
+}
+
 std::string remove_newlines( std::string str ) {
   while (!str.empty() && str.find("\n") != std::string::npos)
     str.erase(std::remove(str.begin(), str.end(), '\n'), str.cend());
