@@ -292,6 +292,7 @@ bool VideoStore::open() {
             av_dict_set(&opts, "reorder_queue_size", nullptr, AV_DICT_MATCH_CASE);
           }
         }
+
         // When encoding, we are going to use the timestamp values instead of packet pts/dts
         video_out_ctx->time_base = AV_TIME_BASE_Q;
         video_out_ctx->codec_id = chosen_codec_data->codec_id;
@@ -301,15 +302,30 @@ bool VideoStore::open() {
         const AVDictionaryEntry *opts_level = av_dict_get(opts, "level", nullptr, AV_DICT_MATCH_CASE);
         if (opts_level) {
           video_out_ctx->level = std::stoul(opts_level->value);
-        } else {
-          video_out_ctx->level = 32;
+        //} else if (!video_out_ctx->level) {
+          //video_out_ctx->level = 32;
         }
         const AVDictionaryEntry *opts_gop_size = av_dict_get(opts, "gop_size", nullptr, AV_DICT_MATCH_CASE);
         if (opts_gop_size) {
           video_out_ctx->gop_size = std::stoul(opts_gop_size->value);
-        } else {
-          video_out_ctx->gop_size = 12;
+          av_dict_set(&opts, "gop_size", nullptr, AV_DICT_MATCH_CASE);
         }
+        //zm_dump_codec(video_out_ctx);
+        const AVDictionaryEntry *opts_bitrate = av_dict_get(opts, "bitrate", nullptr, AV_DICT_MATCH_CASE);
+        if (opts_bitrate) {
+          video_out_ctx->bit_rate = std::stoul(opts_bitrate->value);
+          av_dict_set(&opts, "bitrate", nullptr, AV_DICT_MATCH_CASE);
+        } else {
+          opts_bitrate = av_dict_get(opts, "bit_rate", nullptr, AV_DICT_MATCH_CASE);
+          if (opts_bitrate) {
+            video_out_ctx->bit_rate = std::stoul(opts_bitrate->value);
+            av_dict_set(&opts, "bit_rate", nullptr, AV_DICT_MATCH_CASE);
+          }
+        }
+        //if (!video_out_ctx->bit_rate) {
+          //video_out_ctx->bit_rate = monitor->get_capture_bitrate();
+        //}
+        zm_dump_codec(video_out_ctx);
 
         // Don't have an input stream, so need to tell it what we are sending it, or are transcoding
         video_out_ctx->width = monitor->Width();
@@ -317,7 +333,7 @@ bool VideoStore::open() {
         video_out_ctx->codec_type = AVMEDIA_TYPE_VIDEO;
 
         if (video_out_ctx->codec_id == AV_CODEC_ID_H264) {
-          video_out_ctx->bit_rate = 2000000;
+          if (!video_out_ctx->bit_rate) video_out_ctx->bit_rate = 2000000;
           video_out_ctx->max_b_frames = 1;
         } else if (video_out_ctx->codec_id == AV_CODEC_ID_MPEG2VIDEO) {
           /* just for testing, we also add B frames */
@@ -340,7 +356,12 @@ bool VideoStore::open() {
           av_opt_set(video_out_ctx->priv_data, "enc", std::to_string(devid).c_str(), 0);
         }
 #endif
+        const AVDictionaryEntry *xcoder_params = av_dict_get(opts, "xcoder-params", nullptr, AV_DICT_MATCH_CASE);
+        if (xcoder_params) {
+          av_opt_set(video_out_ctx->priv_data, "xcoder-params", xcoder_params->value, 0);
+        }
 
+        zm_dump_codec(video_out_ctx);
         if ((ret = avcodec_open2(video_out_ctx, video_out_codec, &opts)) < 0) {
           if (wanted_encoder != "" and wanted_encoder != "auto") {
             Warning("Can't open video codec (%s) %s",
@@ -363,6 +384,7 @@ bool VideoStore::open() {
         av_dict_free(&opts);
 
         if (video_out_codec) {
+          zm_dump_codec(video_out_ctx);
           break;
         }
         // We allocate and copy in newer ffmpeg, so need to free it
@@ -384,6 +406,7 @@ bool VideoStore::open() {
         Error("Could not initialize stream parameters");
         return false;
       }
+      zm_dump_stream(video_out_stream);
     }  // end if copying or transcoding
   }  // end if video_in_stream
 
@@ -468,6 +491,15 @@ bool VideoStore::open() {
         } // end if audio_out_ctx
       } // end if audio_out_stream
     } // end if is AAC
+
+    if (oc->oformat->flags & AVFMT_GLOBALHEADER) {
+      audio_out_ctx->flags |= AV_CODEC_FLAG_GLOBAL_HEADER;
+    }
+
+    // We will assume that subsequent stream allocations will increase the index
+    max_stream_index = audio_out_stream->index;
+    last_dts[audio_out_stream->index] = AV_NOPTS_VALUE;
+    reorder_queues[audio_out_stream->index] = {};
   }  // end if audio_in_stream
 
   //max_stream_index is 0-based, so add 1
@@ -488,6 +520,7 @@ bool VideoStore::open() {
   zm_dump_stream_format(oc, 0, 0, 1);
   if (audio_out_stream) zm_dump_stream_format(oc, 1, 0, 1);
 
+  av_dict_set(&opts, "xcoder-params", nullptr, AV_DICT_MATCH_CASE);
   const AVDictionaryEntry *movflags_entry = av_dict_get(opts, "movflags", nullptr, AV_DICT_MATCH_CASE);
   if (!movflags_entry) {
     Debug(1, "setting movflags to frag_keyframe+empty_moov+faststart");
@@ -923,14 +956,14 @@ bool VideoStore::setup_resampler() {
 
   /** Create a new frame to store the audio samples. */
   if (!in_frame) {
-    if (!(in_frame = av_frame_ptr{zm_av_frame_alloc()})) {
+    if (!(in_frame = av_frame_ptr{av_frame_alloc()})) {
       Error("Could not allocate in frame");
       return false;
     }
   }
 
   /** Create a new frame to store the audio samples. */
-  if (!(out_frame = av_frame_ptr{zm_av_frame_alloc()})) {
+  if (!(out_frame = av_frame_ptr{av_frame_alloc()})) {
     Error("Could not allocate out frame");
     return false;
   }
@@ -1116,7 +1149,9 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
 
     if (zm_packet->hw_frame) {
       av_frame_ref(frame.get(), zm_packet->hw_frame.get());
-    } else if (!zm_packet->out_frame) {
+    } else if (zm_packet->out_frame) {
+      av_frame_ref(frame.get(), zm_packet->out_frame.get());
+    } else {
       Debug(3, "Have no out frame. codec is %s sw_pf %d %s hw_pf %d %s %dx%d",
             chosen_codec_data->codec_name,
             chosen_codec_data->sw_pix_fmt, av_get_pix_fmt_name(chosen_codec_data->sw_pix_fmt),
@@ -1147,23 +1182,27 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
               );
         }
       } else if (zm_packet->ai_frame) {
-        Debug(1, "Using ai_frame");
+        Debug(1, "Want ai_frame");
         if (zm_packet->ai_frame->width == video_out_ctx->width
-          and
-          zm_packet->ai_frame->height == video_out_ctx->height
-          and
-          static_cast<AVPixelFormat>(zm_packet->ai_frame->format) == chosen_codec_data->sw_pix_fmt
-          ) {
-            av_frame_ref(frame.get(), zm_packet->ai_frame.get());
-          } else {
-            frame = av_frame_ptr(zm_packet->get_out_frame(video_out_ctx->width, video_out_ctx->height, chosen_codec_data->sw_pix_fmt));
-            if (!frame) {
-              Error("Unable to allocate a frame");
-              return 0;
-            }
-            // Have in_frame.... may need to convert it to out_frame
-            swscale.Convert(zm_packet->ai_frame.get(), frame.get());
+            and
+            zm_packet->ai_frame->height == video_out_ctx->height
+            and
+            static_cast<AVPixelFormat>(zm_packet->ai_frame->format) == chosen_codec_data->sw_pix_fmt
+           ) {
+          Debug(1, "Using ai_frame");
+          av_frame_ref(frame.get(), zm_packet->ai_frame.get());
+        } else {
+          Debug(1, "reating ai_frame");
+          frame = av_frame_ptr(zm_packet->get_out_frame(video_out_ctx->width, video_out_ctx->height, chosen_codec_data->sw_pix_fmt));
+          if (!frame) {
+            Error("Unable to allocate a frame");
+            return 0;
           }
+          av_frame_copy_props(frame.get(), zm_packet->ai_frame.get());
+
+          // Have in_frame.... may need to convert it to out_frame
+          swscale.Convert(zm_packet->ai_frame.get(), frame.get());
+        }
       } else if (zm_packet->in_frame) {
         Debug(1, "Using in_frame");
         if (zm_packet->in_frame->width == video_out_ctx->width
@@ -1174,18 +1213,20 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
            ) {
           av_frame_ref(frame.get(), zm_packet->in_frame.get());
         } else {
+        Debug(1, "Scaling in_frame");
           av_frame_ref(frame.get(), zm_packet->get_out_frame(video_out_ctx->width, video_out_ctx->height, chosen_codec_data->sw_pix_fmt));
           // Have in_frame.... may need to convert it to out_frame
           swscale.Convert(zm_packet->in_frame.get(), frame.get());
+          av_frame_copy_props(frame.get(), zm_packet->in_frame.get());
         }
       } // end if no in_frame
     } // end if no out_frame
 
 #if HAVE_LIBAVUTIL_HWCONTEXT_H
     if (video_out_ctx->hw_frames_ctx and (static_cast<AVPixelFormat>(frame->format) != video_out_ctx->pix_fmt)) {
-      Debug(1, "Using hwframe");
+      zm_dump_frame(frame.get(), "using hwframe, src is");
       int ret;
-      av_frame_ptr hw_frame = av_frame_ptr{zm_av_frame_alloc()};
+      av_frame_ptr hw_frame = av_frame_ptr{av_frame_alloc()};
       if (!hw_frame) {
         return AVERROR(ENOMEM);
       }
@@ -1201,12 +1242,13 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
         Error("Error while transferring frame data to surface: %s.", av_err2str(ret));
         return ret;
       }
-      ret = av_frame_copy_props(frame.get(), hw_frame.get());
+      ret = av_frame_copy_props( hw_frame.get(), frame.get());
       if (ret < 0) {
         Error("Unable to copy props: %s, continuing", av_make_error_string(ret).c_str());
       }
 
       frame = std::move(hw_frame);
+      zm_dump_frame(frame.get(), "using hwframe, dst is");
     }  // end if hwaccel
 #endif
     if (!frame) {
@@ -1237,6 +1279,17 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
       }
     } else {
       if (zm_packet->in_frame) {
+         Debug(2,
+              "pts for frame(%d) to packet pts (%" PRId64 ") from (zm_packet->in_frame(%" PRIi64 " - first %" PRId64 " ) @ %d/%d=>%d/%d",
+              frame_count,
+              zm_packet->packet->pts,
+              zm_packet->in_frame->pts,
+              video_first_pts,
+              video_in_stream->time_base.num,
+              video_in_stream->time_base.den,
+              video_out_ctx->time_base.num,
+              video_out_ctx->time_base.den);
+
         if (video_first_pts == AV_NOPTS_VALUE) {
           video_first_pts = zm_packet->in_frame->pts;
           Debug(2, "No video_first_pts, set to (%" PRId64 ")", video_first_pts);
@@ -1280,16 +1333,18 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
     // Some hwaccel codecs may get full if we only receive one pkt for one frame
 
     do {
+      zm_dump_frame(frame.get(), "sending frame");
       int ret = avcodec_send_frame(video_out_ctx, frame.get());
-      if (ret == AVERROR(EAGAIN) and !zm_terminate) {
-        Debug(1, "Got EAGAIN sending frame");
-        continue;
-      }
       if (ret < 0) {
-        Error("Could not send frame (error '%s')", av_make_error_string(ret).c_str());
-        return ret;
+        if (AVERROR(EAGAIN) != ret) {
+          Error("Could not send frame (error '%s')", av_make_error_string(ret).c_str());
+          return ret;
+        } else {
+          Debug(3, "Got EAGAIN");
+        }
+      } else {
+        break;
       }
-      break;
     } while(!zm_terminate);
 
     while (!zm_terminate) {
@@ -1298,7 +1353,7 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
         if (ret != AVERROR(EAGAIN)) {
           Error("Could not receive packet (error %d = %s)", ret, av_make_error_string(ret).c_str());
         } else {
-          Debug(1, "Could not receive packet (error %d = %s)", ret, av_make_error_string(ret).c_str());
+          Debug(4, "Could not receive packet (error %d = %s)", ret, av_make_error_string(ret).c_str());
         }
         return ret;
       }
@@ -1308,7 +1363,7 @@ int VideoStore::writeVideoFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
       // Need to adjust pts/dts values from codec time to stream time
       if (opkt->pts != AV_NOPTS_VALUE)
         opkt->pts = av_rescale_q(opkt->pts, video_out_ctx->time_base, video_out_stream->time_base);
-      if (opkt->dts != AV_NOPTS_VALUE and opkt->dts > 0)
+      if (opkt->dts != AV_NOPTS_VALUE)// and opkt->dts > 0)
         opkt->dts = av_rescale_q(opkt->dts, video_out_ctx->time_base, video_out_stream->time_base);
       Debug(1, "Timebase conversions using %d/%d -> %d/%d",
             video_out_ctx->time_base.num,
@@ -1431,7 +1486,7 @@ int VideoStore::writeAudioFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
                            audio_out_stream->time_base);
 
       write_packet(opkt.get(), audio_out_stream);
-      zm_av_packet_unref(opkt.get());
+      av_packet_unref(opkt.get());
 
       if (zm_resample_get_delay(resample_ctx, out_frame->sample_rate) < out_frame->nb_samples)
         break;
@@ -1451,8 +1506,8 @@ int VideoStore::writeAudioFramePacket(const std::shared_ptr<ZMPacket> zm_packet)
     ZM_DUMP_STREAM_PACKET(audio_out_stream, opkt, "after stream pts adjustment");
     write_packet(opkt.get(), audio_out_stream);
 
-    zm_av_packet_unref(opkt.get());
-    //zm_av_packet_unref(zm_packet->packet.get());
+    av_packet_unref(opkt.get());
+    //av_packet_unref(zm_packet->packet.get());
   }  // end if encoding or copying
   //ZM_DUMP_STREAM_PACKET(audio_in_stream, ipkt, "input packet");
 
@@ -1480,10 +1535,10 @@ int VideoStore::write_packet(AVPacket *pkt, AVStream *stream) {
         if (pkt->dts > pkt->pts) pkt->pts = pkt->dts; // Do it here to avoid warning below
       } else if (pkt->dts == last_dts[stream->index]) {
         // Commonly seen
-        Debug(1, "non increasing dts, fixing. our dts %" PRId64 " stream %d last_dts %" PRId64 " stream %d. reorder_queue_size=%zu",
-            pkt->dts, stream->index, last_dts[stream->index], stream->index, reorder_queue_size);
+        Debug(1, "non increasing dts, fixing. our dts %" PRId64 " stream %d last_dts %" PRId64 " last duration %" PRId64 " stream %d. reorder_queue_size=%zu",
+            pkt->dts, stream->index, last_dts[stream->index], last_duration[stream->index], stream->index, reorder_queue_size);
         // dts MUST monotonically increase, so add 1 which should be a small enough time difference to not matter.
-        pkt->dts = last_dts[stream->index]+last_duration[stream->index];
+        pkt->dts = last_dts[stream->index]+last_duration[stream->index]-1;
         if (pkt->dts > pkt->pts) pkt->pts = pkt->dts; // Do it here to avoid warning below
       }
     }
