@@ -59,10 +59,10 @@ possible, this should run at more or less constant speed.
 #include "zm_define.h"
 #include "zm_fifo.h"
 #include "zm_monitor.h"
-#include "zm_rtsp_server_thread.h"
 #include "zm_signal.h"
 #include "zm_time.h"
 #include "zm_utils.h"
+
 #include <getopt.h>
 #include <iostream>
 #include <unistd.h>
@@ -83,7 +83,7 @@ void Usage() {
   exit(0);
 }
 
-int main(int argc, char *argv[]) {
+int main(int argc, char *argv[], char **envp) {
   self = argv[0];
 
   srand(getpid() * time(nullptr));
@@ -118,34 +118,34 @@ int main(int argc, char *argv[]) {
     }
 
     switch (c) {
-      case 'd':
-        device = optarg;
-        break;
-      case 'H':
-        host = optarg;
-        break;
-      case 'P':
-        port = optarg;
-        break;
-      case 'p':
-        path = optarg;
-        break;
-      case 'f':
-        file = optarg;
-        break;
-      case 'm':
-        monitor_id = atoi(optarg);
-        break;
-      case 'h':
-      case '?':
-        Usage();
-        break;
-      case 'v':
-        std::cout << ZM_VERSION << "\n";
-        exit(0);
-      default:
-        // fprintf(stderr, "?? getopt returned character code 0%o ??\n", c);
-        break;
+    case 'd':
+      device = optarg;
+      break;
+    case 'H':
+      host = optarg;
+      break;
+    case 'P':
+      port = optarg;
+      break;
+    case 'p':
+      path = optarg;
+      break;
+    case 'f':
+      file = optarg;
+      break;
+    case 'm':
+      monitor_id = atoi(optarg);
+      break;
+    case 'h':
+    case '?':
+      Usage();
+      break;
+    case 'v':
+      std::cout << ZM_VERSION << "\n";
+      exit(0);
+    default:
+      // fprintf(stderr, "?? getopt returned character code 0%o ??\n", c);
+      break;
     }
   }
 
@@ -189,32 +189,40 @@ int main(int argc, char *argv[]) {
   zmLoadDBConfig();
   logInit(log_id_string);
 
+
+  for (char **env = envp; *env != 0; env++) {
+    char *thisEnv = *env;
+    Debug(1, "env: %s", thisEnv);
+  }
+
+  getcpu();
   HwCapsDetect();
+  curl_global_init(CURL_GLOBAL_DEFAULT);
 
   std::vector<std::shared_ptr<Monitor>> monitors;
-#if ZM_HAS_V4L
+#if ZM_HAS_V4L2
   if ( device[0] ) {
     monitors = Monitor::LoadLocalMonitors(device, Monitor::CAPTURE);
   } else
-#endif  // ZM_HAS_V4L
-  if ( host[0] ) {
-    if ( !port )
-      port = "80";
-    monitors = Monitor::LoadRemoteMonitors(protocol, host, port, path, Monitor::CAPTURE);
-  } else if ( file[0] ) {
-    monitors = Monitor::LoadFileMonitors(file, Monitor::CAPTURE);
-  } else {
-    std::shared_ptr<Monitor> monitor = Monitor::Load(monitor_id, true, Monitor::CAPTURE);
-    if ( monitor ) {
-      monitors.push_back(monitor);
+#endif  // ZM_HAS_V4L2
+    if ( host[0] ) {
+      if ( !port )
+        port = "80";
+      monitors = Monitor::LoadRemoteMonitors(protocol, host, port, path, Monitor::CAPTURE);
+    } else if ( file[0] ) {
+      monitors = Monitor::LoadFileMonitors(file, Monitor::CAPTURE);
+    } else {
+      std::shared_ptr<Monitor> monitor = Monitor::Load(monitor_id, true, Monitor::CAPTURE);
+      if ( monitor ) {
+        monitors.push_back(monitor);
+      }
     }
-  }
 
   if (monitors.empty()) {
     Error("No monitors found");
     exit(-1);
   } else {
-	  Debug(2, "%zu monitors loaded", monitors.size());
+    Debug(2, "%zu monitors loaded", monitors.size());
   }
 
   Info("Starting Capture version %s", ZM_VERSION);
@@ -222,79 +230,98 @@ int main(int argc, char *argv[]) {
   zmSetDefaultTermHandler();
   zmSetDefaultDieHandler();
 
-  sigset_t block_set;
-  sigemptyset(&block_set);
-
-  sigaddset(&block_set, SIGHUP);
-  sigaddset(&block_set, SIGUSR1);
-  sigaddset(&block_set, SIGUSR2);
+  struct sigaction sa;
+  sa.sa_handler = SIG_IGN; //handle signal by ignoring
+  sigemptyset(&sa.sa_mask);
+  sa.sa_flags = 0;
+  if (sigaction(SIGCHLD, &sa, 0) == -1) {
+    Error("Unable to set SIGCHLD to ignore. There may be zombies.");
+  }
 
   int result = 0;
   int prime_capture_log_count = 0;
 
   while (!zm_terminate) {
     result = 0;
-    static char sql[ZM_SQL_SML_BUFSIZ];
 
     for (const std::shared_ptr<Monitor> &monitor : monitors) {
-      monitor->LoadCamera();
-
-      if (!monitor->connect()) {
-        Warning("Couldn't connect to monitor %d", monitor->Id());
-      }
-      time_t now = (time_t)time(nullptr);
-      monitor->setStartupTime(now);
-      monitor->setHeartbeatTime(now);
-
-      snprintf(sql, sizeof(sql), 
-          "INSERT INTO Monitor_Status (MonitorId,Status,CaptureFPS,AnalysisFPS,UpdatedOn)"
-          " VALUES (%u, 'Running',0,0,NOW()) ON DUPLICATE KEY UPDATE Status='Running',CaptureFPS=0,AnalysisFPS=0,CaptureBandwidth=0,UpdatedOn=NOW()",
-          monitor->Id());
+      std::string sql = stringtf(
+                          "INSERT INTO Monitor_Status (MonitorId,Status,CaptureFPS,AnalysisFPS,CaptureBandwidth)"
+                          " VALUES (%u, 'Running',0,0,0) ON DUPLICATE KEY UPDATE Status='Running',CaptureFPS=0,AnalysisFPS=0,CaptureBandwidth=0",
+                          monitor->Id());
       zmDbDo(sql);
 
-      int sleep_time = 0;
-      while (monitor->PrimeCapture() <= 0) {
-        if (prime_capture_log_count % 60) {
-          logPrintf(Logger::ERROR+monitor->Importance(),
-              "Failed to prime capture of initial monitor");
-        } else {
-          Debug(1, "Failed to prime capture of initial monitor");
-        }
-        prime_capture_log_count ++;
-        if (zm_terminate) break;
-        if (sleep_time < 60) sleep_time++;
-        sleep(sleep_time);
+      monitor->LoadCamera();
+
+      while (!monitor->connect() and !zm_terminate) {
+        Warning("Couldn't connect to monitor %d", monitor->Id());
+        sleep(1);
       }
       if (zm_terminate) break;
 
-      snprintf(sql, sizeof(sql),
-          "INSERT INTO Monitor_Status (MonitorId,Status,UpdatedOn) VALUES (%u, 'Connected', NOW()) ON DUPLICATE KEY UPDATE Status='Connected',UpdatedOn=NOW()",
-               monitor->Id());
+      SystemTimePoint now = std::chrono::system_clock::now();
+      monitor->SetStartupTime(now);
+
+      if (monitor->StartupDelay() > 0) {
+        Debug(1, "Doing startup sleep for %ds", monitor->StartupDelay());
+        std::this_thread::sleep_for(Seconds(monitor->StartupDelay()));
+      }
+
+      Seconds sleep_time = Seconds(0);
+      while ((monitor->PrimeCapture() <= 0) and !zm_terminate) {
+        if (prime_capture_log_count % 60) {
+          logPrintf(Logger::ERROR + monitor->Importance(), "Failed to prime capture of initial monitor");
+        } else {
+          Debug(1, "Failed to prime capture of initial monitor");
+        }
+
+        prime_capture_log_count++;
+        if (sleep_time < Seconds(ZM_WATCH_MAX_DELAY)) {
+          sleep_time++;
+        }
+
+        std::this_thread::sleep_for(sleep_time);
+        monitor->SetHeartbeatTime(std::chrono::system_clock::now());
+      }
+      if (zm_terminate) break;
+
+      sql = stringtf(
+              "INSERT INTO Monitor_Status (MonitorId,Status) VALUES (%u, 'Connected') ON DUPLICATE KEY UPDATE Status='Connected'",
+              monitor->Id());
       zmDbDo(sql);
     }  // end foreach monitor
+
     if (zm_terminate) break;
 
-    int *capture_delays = new int[monitors.size()];
-    int *alarm_capture_delays = new int[monitors.size()];
-    struct timeval * last_capture_times = new struct timeval[monitors.size()];
-
-    for (size_t i = 0; i < monitors.size(); i++) {
-      last_capture_times[i].tv_sec = last_capture_times[i].tv_usec = 0;
-      capture_delays[i] = monitors[i]->GetCaptureDelay();
-      alarm_capture_delays[i] = monitors[i]->GetAlarmCaptureDelay();
-      Debug(2, "capture delay(%u mSecs 1000/capture_fps) alarm delay(%u)",
-          capture_delays[i], alarm_capture_delays[i]);
-    }
-
-    struct timeval now;
-    struct DeltaTimeval delta_time;
-    int sleep_time = 0;
+    std::vector<SystemTimePoint> last_capture_times = std::vector<SystemTimePoint>(monitors.size());
+    Microseconds sleep_time = Microseconds(0);
 
     while (!zm_terminate) {
-      //sigprocmask(SIG_BLOCK, &block_set, 0);
       for (size_t i = 0; i < monitors.size(); i++) {
         monitors[i]->CheckAction();
 
+        if (monitors[i]->Capturing() == Monitor::CAPTURING_ONDEMAND) {
+          SystemTimePoint now = std::chrono::system_clock::now();
+          monitors[i]->SetHeartbeatTime(now);
+
+          time_t last_viewed = monitors[i]->getLastViewed();
+          int64 since_last_view = static_cast<int64>(std::chrono::duration_cast<Seconds>(now.time_since_epoch()).count()) - last_viewed;
+          Debug(1, "Last view %jd= %" PRId64 " seconds since last view", last_viewed, since_last_view);
+          if (((!last_viewed) or (since_last_view > 10)) and (monitors[i]->GetLastWriteIndex() != -1)) {
+            if (monitors[i]->getCamera()->isPrimed()) {
+              monitors[i]->Pause();
+            }
+            std::this_thread::sleep_for(Microseconds(100000));
+            result = 0;
+            continue;
+          } else if (!monitors[i]->getCamera()->isPrimed()) {
+            if (1 > (result = monitors[i]->Play())) {
+              Debug(1, "Failed to play");
+              break;
+            }
+          }
+        } // end if ONDEMAND
+
         if (monitors[i]->PreCapture() < 0) {
           Error("Failed to pre-capture monitor %d %s (%zu/%zu)",
                 monitors[i]->Id(), monitors[i]->Name(), i + 1, monitors.size());
@@ -302,7 +329,7 @@ int main(int argc, char *argv[]) {
           break;
         }
         if (monitors[i]->Capture() < 0) {
-          Error("Failed to capture image from monitor %d %s (%zu/%zu)",
+          logPrintf(Logger::ERROR + monitors[i]->Importance(), "Failed to capture image from monitor %d %s (%zu/%zu)",
                 monitors[i]->Id(), monitors[i]->Name(), i + 1, monitors.size());
           result = -1;
           break;
@@ -313,33 +340,42 @@ int main(int argc, char *argv[]) {
           result = -1;
           break;
         }
-        monitors[i]->UpdateFPS();
+
+        if (!result) monitors[i]->UpdateFPS();
+
+        SystemTimePoint now = std::chrono::system_clock::now();
+        monitors[i]->SetHeartbeatTime(now);
 
         // capture_delay is the amount of time we should sleep in useconds to achieve the desired framerate.
-        int delay = (monitors[i]->GetState() == Monitor::ALARM) ? alarm_capture_delays[i] : capture_delays[i];
-        if (delay) {
-          gettimeofday(&now, nullptr);
-          if (last_capture_times[i].tv_sec) {
-            // DT_PREC_3 means that the value will be in thousands of a second
-            DELTA_TIMEVAL(delta_time, now, last_capture_times[i], DT_PREC_6);
+        Microseconds delay = (monitors[i]->GetState() == Monitor::ALARM) ? monitors[i]->GetAlarmCaptureDelay()
+                             : monitors[i]->GetCaptureDelay();
+        if (delay != Microseconds(0)) {
+          if (last_capture_times[i].time_since_epoch() != Seconds(0)) {
+            Microseconds delta_time = std::chrono::duration_cast<Microseconds>(now - last_capture_times[i]);
 
             // You have to add back in the previous sleep time
-            sleep_time = delay - (delta_time.delta - sleep_time);
-            Debug(4,
-                  "Sleep time is %d from now: %" PRIi64 ".%" PRIi64" last: %" PRIi64 ".% " PRIi64 " delta %lu delay: %d",
-                  sleep_time,
-                  static_cast<int64>(now.tv_sec),
-                  static_cast<int64>(now.tv_usec),
-                  static_cast<int64>(last_capture_times[i].tv_sec),
-                  static_cast<int64>(last_capture_times[i].tv_usec),
-                  delta_time.delta,
-                  delay);
+            sleep_time = delay - (delta_time - sleep_time);
 
-            if (sleep_time > 0) {
-              Debug(4, "usleeping (%d)", sleep_time);
-              usleep(sleep_time);
+            // Limit negative since feedback - if an error occurred can loose seconds and then run too fast for a while so rather accept the frame loss
+            // Or if the camera exposure is longer than intended FPS (eg at night) don't build up a huge negative that will disable the FPS limit later and OOM (eg at dawn)
+            if (sleep_time < (delay * -1)) {
+              sleep_time = delay * -1;
+            }
+
+            Debug(4,
+                  "Sleep time is %" PRIi64 " us from now: %.3f s last: %.3f s delta % " PRIi64 " us delay: %" PRIi64 " us",
+                  static_cast<int64>(Microseconds(sleep_time).count()),
+                  FPSeconds(now.time_since_epoch()).count(),
+                  FPSeconds(last_capture_times[i].time_since_epoch()).count(),
+                  static_cast<int64>(delta_time.count()),
+                  static_cast<int64>(Microseconds(delay).count()));
+
+            // When negative the capture took more than the configured FPS time and no need to sleep
+            if (sleep_time > Microseconds(0)) {
+              std::this_thread::sleep_for(sleep_time);
             }
           }  // end if has a last_capture time
+
           last_capture_times[i] = now;
         }  // end if delay
       }  // end foreach n_monitors
@@ -350,40 +386,39 @@ int main(int argc, char *argv[]) {
       }
     }  // end while ! zm_terminate and connected
 
-    for (size_t i = 0; i < monitors.size(); i++) {
-      monitors[i]->Close();
-      monitors[i]->disconnect();
+    for (std::shared_ptr<Monitor> & monitor : monitors) {
+      monitor->Close();
+      monitor->disconnect();
     }
 
-    delete [] alarm_capture_delays;
-    delete [] capture_delays;
-    delete [] last_capture_times;
-
     if (zm_reload) {
+      zmLoadStaticConfig();
+      zmLoadDBConfig();
       for (std::shared_ptr<Monitor> &monitor : monitors) {
         monitor->Reload();
       }
       logTerm();
       logInit(log_id_string);
-      
+
       zm_reload = false;
     }  // end if zm_reload
   }  // end while ! zm_terminate outer connection loop
 
   for (std::shared_ptr<Monitor> &monitor : monitors) {
-    static char sql[ZM_SQL_SML_BUFSIZ];
-    snprintf(sql, sizeof(sql),
-        "INSERT INTO Monitor_Status (MonitorId,Status,UpdatedOn) VALUES (%u, 'NotRunning') ON DUPLICATE KEY UPDATE Status='NotRunning',CaptureFPS=0,AnalysisFPS=0,CaptureBandwidth=0,NOW()", 
-        monitor->Id());
+    std::string sql = stringtf(
+                        "INSERT INTO Monitor_Status (MonitorId,Status) VALUES (%u, 'NotRunning') ON DUPLICATE KEY UPDATE Status='NotRunning',CaptureFPS=0,AnalysisFPS=0,CaptureBandwidth=0",
+                        monitor->Id());
     zmDbDo(sql);
   }
   monitors.clear();
+  Debug(1, "Cleared monitors");
 
   Image::Deinitialise();
+  curl_global_cleanup();
   Debug(1, "terminating");
   dbQueue.stop();
-  logTerm();
   zmDbClose();
+  logTerm();
 
-	return zm_terminate ? 0 : result;
+  return zm_terminate ? 0 : result;
 }
