@@ -15,8 +15,6 @@ if [ "$DEBUILD" == "" ]; then
   exit;
 fi
 
-sudo apt-get install debhelper sphinx-doc python3-sphinx dh-linktree dh-apache2 libavcodec-dev libavdevice-dev libavformat-dev libavutil-dev libswresample-dev libswscale-dev ffmpeg libbz2-dev libjpeg-turbo8-dev libpolkit-gobject-1-dev libv4l-dev libvlc-dev libdate-manip-perl libdbd-mysql-perl libphp-serialization-perl libsys-mmap-perl libdata-uuid-perl libssl-dev libcrypt-eksblowfish-perl libdata-entropy-perl libvncserver-dev libgsoap-dev
-
 for i in "$@"
 do
 case $i in
@@ -89,11 +87,7 @@ else
 fi;
 
 if [ "$DISTROS" == "" ]; then
-  if [ "$RELEASE" != "" ]; then
-    DISTROS="xenial,bionic,focal,jammy,kinetic"
-  else
-    DISTROS=`lsb_release -a 2>/dev/null | grep Codename | awk '{print $2}'`;
-  fi;
+  DISTROS=`lsb_release -a 2>/dev/null | grep Codename | awk '{print $2}'`;
   echo "Defaulting to $DISTROS for distribution";
 else
   echo "Building for $DISTROS";
@@ -118,55 +112,6 @@ else
     echo "Defaulting to ZoneMinder upstream git"
     GITHUB_FORK="ZoneMinder"
   fi;
-  if [ "$SNAPSHOT" == "stable" ]; then
-    if [ "$BRANCH" == "" ]; then
-      #REV=$(git rev-list --tags --max-count=1)
-      BRANCH=`git describe --tags $(git rev-list --tags --max-count=1)`;
-      if [ -z "$BRANCH" ]; then
-        # This should only happen in CI environments where tag info isn't available
-        BRANCH=$(cat "$(find . -name 'version' -o -name 'version.txt')")
-        echo "Building branch $BRANCH"
-      fi
-      if [ "$BRANCH" == "" ]; then
-        echo "Unable to determine latest stable branch!"
-        exit 0;
-      fi
-      echo "Latest stable branch is $BRANCH";
-    fi;
-  else
-    if [ "$BRANCH" == "" ]; then
-      echo "Defaulting to master branch";
-      BRANCH="master";
-    fi;
-  fi;
-fi
-
-if [ "$PACKAGE_VERSION" == "NOW" ]; then
-  PACKAGE_VERSION=`date +%Y%m%d%H%M%S`;
-else
-  if [ "$PACKAGE_VERSION" == "CURRENT" ]; then
-    # git the latest (short) commit hash of the version file
-    versionhash=$(git log -n1 --pretty=format:%h version)
-    PACKAGE_VERSION="`date +%Y%m%d.`$(git rev-list ${versionhash}..HEAD --count)"
-  fi;
-fi;
-
-IFS='.' read -r -a VERSION_PARTS <<< "$RELEASE"
-if [ "$PPA" == "" ]; then
-  if [ "$RELEASE" != "" ]; then
-    # We need to use our official tarball for the original source, so grab it and overwrite our generated one.
-    if [ "${VERSION_PARTS[0]}.${VERSION_PARTS[1]}" == "1.30" ]; then
-      PPA="ppa:iconnor/zoneminder-stable"
-    else
-      PPA="ppa:iconnor/zoneminder-${VERSION_PARTS[0]}.${VERSION_PARTS[1]}"
-    fi;
-  else
-    if [ "$BRANCH" == "" ]; then
-      PPA="ppa:iconnor/zoneminder-master";
-    else
-      PPA="ppa:iconnor/zoneminder-$BRANCH";
-    fi;
-  fi;
 fi;
 
 # Instead of cloning from github each time, if we have a fork lying around, update it and pull from there instead.
@@ -174,17 +119,10 @@ if [ ! -d "${GITHUB_FORK}_zoneminder_release" ]; then
   if [ -d "${GITHUB_FORK}_ZoneMinder.git" ]; then
     echo "Using local clone ${GITHUB_FORK}_ZoneMinder.git to pull from."
     cd "${GITHUB_FORK}_ZoneMinder.git"
-    echo "git fetch..."
-    git fetch
-    echo "git checkout $BRANCH"
-    git checkout $BRANCH
-    if [ $? -ne 0 ]; then
-      echo "Failed to switch to branch."
-      exit 1;
-    fi;
     echo "git pull..."
     git pull
     cd ../
+
     echo "git clone ${GITHUB_FORK}_ZoneMinder.git ${GITHUB_FORK}_zoneminder_release"
     git clone "${GITHUB_FORK}_ZoneMinder.git" "${GITHUB_FORK}_zoneminder_release"
   else
@@ -197,23 +135,59 @@ else
 fi;
 
 cd "${GITHUB_FORK}_zoneminder_release"
-git checkout $BRANCH
 
-VERSION=$(cat "$(find . -name 'version' -o -name 'version.txt')")
-if [ "$SNAPSHOT" == "NOW" ]; then
-  SNAPSHOT=`date +%Y%m%d%H%M%S`;
+if [ "$SNAPSHOT" == "stable" ]; then
+  if [ "$BRANCH" == "" ]; then
+    #REV=$(git rev-list --tags --max-count=1)
+    BRANCH=`git describe --tags $(git rev-list --tags --max-count=1)`;
+    if [ -z "$BRANCH" ]; then
+      # This should only happen in CI environments where tag info isn't available
+      BRANCH=$(cat "$(find . -maxdepth 1 -name 'version' -o -name 'version.txt')")
+      echo "Building branch $BRANCH"
+    fi
+    if [ "$BRANCH" == "" ]; then
+      echo "Unable to determine latest stable branch!"
+      exit 0;
+    fi
+    echo "Latest stable branch is $BRANCH";
+  fi;
 else
-  if [ "$SNAPSHOT" == "CURRENT" ]; then
-    # git the latest (short) commit hash of the version file
-    versionhash=$(git log -n1 --pretty=format:%h version)
-    SNAPSHOT="`date +%Y%m%d.`$(git rev-list ${versionhash}..HEAD --count)"
+  if [ "$BRANCH" == "" ]; then
+    echo "Defaulting to master branch";
+    BRANCH="master";
+  fi;
+  if [ "$SNAPSHOT" == "NOW" ]; then
+    SNAPSHOT=`date +%Y%m%d%H%M%S`;
+  else
+    if [ "$SNAPSHOT" == "CURRENT" ]; then
+      # git the latest (short) commit hash of the version file
+      versionhash=$(git log -n1 --pretty=format:%h version.txt)
+
+      # Number of commits since the version file was last changed
+      numcommits=$(git rev-list ${versionhash}..HEAD --count)
+      SNAPSHOT="`date +%Y%m%d.`$(git rev-list ${versionhash}..HEAD --count)"
+    fi;
   fi;
 fi;
-cd ../
 
+
+echo "git checkout $BRANCH"
+git checkout $BRANCH
+if [ $? -ne 0 ]; then
+  echo "Failed to switch to branch."
+  exit 1;
+fi;
+echo "git pull..."
+git pull
+# Grab the ZoneMinder version from the contents of the version file
+VERSION=$(cat "$(find . -maxdepth 1 -name 'version' -o -name 'version.txt')")
 if [ -z "$VERSION" ]; then
   exit 1;
 fi;
+IFS='.' read -r -a VERSION_PARTS <<< "$VERSION"
+
+cd ../
+
 if [ "$SNAPSHOT" != "stable" ] && [ "$SNAPSHOT" != "" ]; then
   VERSION="$VERSION~$SNAPSHOT";
 fi;
@@ -244,11 +218,13 @@ rm .gitignore
 cd ../
 
 
-if [ ! -e "$DIRECTORY.orig.tar.gz" ]; then
-  read -p "$DIRECTORY.orig.tar.gz does not exist, create it? [Y/n]"
+if [ -e "$DIRECTORY.orig.tar.gz" ]; then
+  read -p "$DIRECTORY.orig.tar.gz exists, overwrite it? [Y/n]"
   if [[ "$REPLY" == "" || "$REPLY" == [yY] ]]; then
     tar zcf $DIRECTORY.orig.tar.gz $DIRECTORY.orig
   fi;
+else
+  tar zcf $DIRECTORY.orig.tar.gz $DIRECTORY.orig
 fi;
 
 IFS=',' ;for DISTRO in `echo "$DISTROS"`; do 
@@ -259,11 +235,8 @@ IFS=',' ;for DISTRO in `echo "$DISTROS"`; do
     rm -rf debian
   fi;
 
-  # Generate Changlog
-  if [ "$DISTRO" == "xenial" ] || [ "$DISTRO" == "stretch" ]; then
-    cp -Rpd distros/ubuntu1604 debian
-  elif [ "$DISTRO" == "beowulf" ]
-  then
+  # Generate Changelog
+  if [ "$DISTRO" == "beowulf" ]; then
     cp -Rpd distros/beowulf debian
   else
     cp -Rpd distros/ubuntu2004 debian
@@ -319,14 +292,14 @@ EOF
   # Leave the .orig so that we don't pollute it when building deps
   cd ..
   if [ $TYPE == "binary" ]; then
-	  # Auto-install all ZoneMinder's depedencies using the Debian control file
+	  # Auto-install all ZoneMinder's dependencies using the Debian control file
 	  sudo apt-get install devscripts equivs
 	  sudo mk-build-deps -ir $DIRECTORY.orig/debian/control
 	  echo "Status: $?"
 	  DEBUILD=debuild
   else
 	  if [ $TYPE == "local" ]; then
-		  # Auto-install all ZoneMinder's depedencies using the Debian control file
+		  # Auto-install all ZoneMinder's dependencies using the Debian control file
 		  sudo apt-get install devscripts equivs
 		  sudo mk-build-deps -ir $DIRECTORY.orig/debian/control
 		  echo "Status: $?"
@@ -362,6 +335,7 @@ EOF
       read -p "Do you want to upload this binary to zmrepo? (y/N)"
       if [[ $REPLY == [yY] ]]; then
         if [ "$RELEASE" != "" ]; then
+          echo "scp \"zoneminder_${VERSION}-${DISTRO}\"* \"zoneminder-doc_${VERSION}-${DISTRO}\"* \"zoneminder-dbg_${VERSION}-${DISTRO}\"* \"zoneminder_${VERSION}.orig.tar.gz\" \"zmrepo@zmrepo.connortechnology.com:debian/release-${VERSION_PARTS[0]}.${VERSION_PARTS[1]}/mini-dinstall/incoming/\"";
           scp "zoneminder_${VERSION}-${DISTRO}"* "zoneminder-doc_${VERSION}-${DISTRO}"* "zoneminder-dbg_${VERSION}-${DISTRO}"* "zoneminder_${VERSION}.orig.tar.gz" "zmrepo@zmrepo.connortechnology.com:debian/release-${VERSION_PARTS[0]}.${VERSION_PARTS[1]}/mini-dinstall/incoming/"
         else
           if [ "$BRANCH" == "" ]; then
@@ -374,24 +348,40 @@ EOF
     fi;
   else
     SC="zoneminder_${VERSION}-${DISTRO}${PACKAGE_VERSION}_source.changes";
+    if [ "$PPA" == "" ]; then
+      if [ "$RELEASE" != "" ]; then
+        # We need to use our official tarball for the original source, so grab it and overwrite our generated one.
+        if [ "${VERSION_PARTS[0]}.${VERSION_PARTS[1]}" == "1.30" ]; then
+          PPA="ppa:iconnor/zoneminder-stable"
+        else
+          PPA="ppa:iconnor/zoneminder-${VERSION_PARTS[0]}.${VERSION_PARTS[1]}"
+        fi;
+      else
+        if [ "$BRANCH" == "" ]; then
+          PPA="ppa:iconnor/zoneminder-master";
+        else
+          PPA="ppa:iconnor/zoneminder-$BRANCH";
+        fi;
+      fi;
+    fi;
 
     dput="Y";
     if [ "$INTERACTIVE" != "no" ]; then
       read -p "Ready to dput $SC to $PPA ? Y/n...";
       if [[ "$REPLY" == "" || "$REPLY" == [yY] ]]; then
-        dput $PPA $SC
+        dput -d $PPA $SC
       fi;
     else
       if [ "$DPUT" != "no" ]; then
         echo "dputting to $PPA";
-        dput $PPA $SC
+        dput -d $PPA $SC
       fi;
     fi;
   fi;
 done; # foreach distro
 
 if [ "$INTERACTIVE" != "no" ]; then
-  read -p "Do you want to keep the checked out version of Zoneminder (incase you want to modify it later) [y/N]"
+  read -p "Do you want to keep the checked out version of Zoneminder (in case you want to modify it later) [y/N]"
   [[ $REPLY == [yY] ]] && { mv "$DIRECTORY.orig" zoneminder_release; echo "The checked out copy is preserved in zoneminder_release"; } || { rm -fr "$DIRECTORY.orig"; echo "The checked out copy has been deleted"; }
   echo "Done!"
 else 
