@@ -66,6 +66,29 @@ class EventsController extends AppController {
         }
       }
       $conditions = $this->FilterComponent->buildFilter($named_params);
+      foreach ($conditions as $k=>$v) {
+        if ( 0 === strpos($k, 'DateTime') ) {
+          $new_start = preg_replace('/DateTime/', 'StartDateTime', $k);
+          $new_end = preg_replace('/DateTime/', 'EndDateTime', $k);
+          if (isset($conditions['OR'])) {
+            $conditions['AND'] = [
+              ['OR' => $conditions['OR']],
+              [
+                [$new_start => $conditions[$k]],
+                [$new_end => $conditions[$k]]
+              ]
+            ];
+            unset($conditions['OR']);
+          } else {
+            $conditions['OR'] = [
+              [$new_start => $conditions[$k]],
+              [$new_end => $conditions[$k]]
+            ];
+          }
+          unset($conditions[$k]);
+        }
+      } // end foreach condition
+
     } else {
       $conditions = $this->FilterComponent->buildFilter($_REQUEST);
     }
@@ -147,6 +170,11 @@ class EventsController extends AppController {
 
     $options = array('conditions' => array(array('Event.' . $this->Event->primaryKey => $id), $mon_options));
     $event = $this->Event->find('first', $options);
+    $EventObj = new ZM\Event($event['Event']);
+    if (!$EventObj->canView()) {
+      throw new UnauthorizedException(__('Insufficient Privileges'));
+      return;
+    }
 
     # Get the previous and next events for any monitor
     $this->Event->id = $id;
@@ -156,8 +184,6 @@ class EventsController extends AppController {
 
     $event['Event']['fileExists'] = $this->Event->fileExists($event['Event']);
     $event['Event']['fileSize'] = $this->Event->fileSize($event['Event']);
-
-    $EventObj = new ZM\Event($id);
     $event['Event']['FileSystemPath'] = $EventObj->Path();
 
     # Also get the previous and next events for the same monitor
