@@ -202,7 +202,8 @@ class Monitor extends ZM_Object {
     if (!isset($RTSP2WebStreamOptions)) {
       $RTSP2WebStreamOptions = array(
         'Primary' => translate('Primary'),
-        'Secondary' => translate('Secondary')
+        'Secondary' => translate('Secondary'),
+        'Restream' => translate('Restream')
       );
     }
     return $RTSP2WebStreamOptions;
@@ -224,6 +225,10 @@ class Monitor extends ZM_Object {
     'RecordingSource' => 'Primary',
     'AnalysisSource' => 'Primary',
     'AnalysisImage' => 'FullColour',
+    'ObjectDetection' => 'None',
+    'ObjectDetectionModel' => '',
+    'ObjectDetectionObjectThreshold' => '0.4',
+    'ObjectDetectionNMSThreshold' => '0.25',
     'Enabled'   => array('type'=>'boolean','default'=>1),
     'Decoding'  => 'Always',
     'RTSP2WebEnabled'   => array('type'=>'integer','default'=>0),
@@ -276,8 +281,10 @@ class Monitor extends ZM_Object {
     'SaveJPEGs' =>  0,
     'VideoWriter' =>  '2',
     'OutputCodecName' =>  'auto',
-    'Encoder'     =>  'auto',
     'OutputContainer' => null,
+    'Encoder'     =>  'auto',
+    'EncoderHWAccelName'  =>  null,
+    'EncoderHWAccelDevice'  =>  null,
     'EncoderParameters' => '',
     'WallClockTimestamps' => array('type'=>'boolean', 'default'=>0),
     'RecordAudio' =>  array('type'=>'boolean', 'default'=>0),
