@@ -22,8 +22,81 @@ require_once('session.php');
 require_once('User.php');
 require_once('Group_Permission.php');
 require_once('Monitor_Permission.php');
+
 require_once(__DIR__.'/../vendor/autoload.php');
-use \Firebase\JWT\JWT;
+
+if (ZM_AUTH_TYPE == 'oAuth') {
+  require_once 'oAuth.php';
+
+  $oAuth = new oAuth();
+  $oAuthSession = $oAuth->oAuthSession;
+  if ($oAuthSession) {
+    if (isset($_GET['code'])) {
+      if (!$oAuth->check_code($_GET['code'])) {
+        ZM\Debug('Redir to where we came from'.$oAuthSession['Redir']);
+        #$oAuth->logout();
+        global $redirect;
+        $redirect = $oAuthSession['Redir'];
+        return;
+      }
+    } else if (isset($_POST['action']) and ($_POST['action'] == 'login')) {
+      $oAuth->login($_POST['username'], $_POST['password']);
+    } else if (isset($_POST['action']) and ($_POST['action'] == 'logout')) {
+      $oAuth->logout();
+      userLogout();
+      return;
+    }
+
+    if ($oAuth->isLoggedIn) {
+      $username = $oAuth->preferred_username();
+      if ($username) {
+        global $user;
+        $user = ZM\User::find_one(['Username'=>$username]);
+
+        if (!$user) {
+          $user = ZM\User::find_one(['Username'=>'default']);
+          if (!$user) $user = new ZM\User();
+          $user->Id(null);
+          $user->save([
+            'Username'  => $username,
+            'Name'      => $profile->displayName,
+            'Email'     => to_string($profile->mail),
+            'Phone'     => to_string($profile->businessPhones),
+          ]);
+        } else {
+          $profile = $oAuth->Graph()->getProfile();
+          # Check for new values
+          $changes = $user->changes([
+            'Name'      => $profile->displayName,
+            'Email'     => to_string($profile->mail),
+            'Phone'     => to_string($profile->businessPhones),
+          ]);
+          if ($changes != []) {
+            $user->save($changes);
+          }
+        }
+          #$groups = $oAuth->Graph()->getMyGroups();
+          #foreach ($groups as $group) {
+            #ZM\Debug(print_r($group, true));
+          #}
+        $_SESSION['username'] = $user->Username();
+        generateAuthHash(ZM_AUTH_HASH_IPS);
+
+        if (isset($_GET['code'])) {
+          global $redirect;
+          $redirect = '?view='.$user->HomeView();
+        }
+      } # end if username
+    } else {
+      $oAuth->redirect_to_login();
+    }
+  } else {
+    ZM\Error("No oAuthSession");
+    header('Location: /');
+    session_write_close();
+    exit;
+  }
+}
 
 function password_type($password) {
    if ( $password[0] == '*' ) {
@@ -120,7 +193,8 @@ function validateToken($token, $allowed_token_type='access') {
   $key = ZM_AUTH_HASH_SECRET;
   //if (ZM_AUTH_HASH_IPS) $key .= $_SERVER['REMOTE_ADDR'];
   try {
-    $decoded_token = JWT::decode($token, $key, array('HS256'));
+    $headers = new \stdClass();
+    $decoded_token = Firebase\JWT\JWT::decode($token, new Firebase\JWT\Key($key, 'HS256'), $headers);
   } catch (Exception $e) {
     ZM\Error("Unable to authenticate user. error decoding JWT token:".$e->getMessage());
     return array(false, $e->getMessage());
@@ -407,100 +481,101 @@ if (ZM_OPT_USE_AUTH) {
     $user = $ret[0];
   } else {
     // Non token based auth
-
-    if (ZM_AUTH_HASH_LOGINS && empty($user) && !empty($_REQUEST['auth'])) {
-      $user = getAuthUser($_REQUEST['auth']);
-    } else if (!(empty($_REQUEST['user']) or empty($_REQUEST['pass']))) {
-      # The shortened versions are used in auth_relay = PLAIN
-      $ret = validateUser($_REQUEST['user'], $_REQUEST['pass']);
-      if (!$ret[0]) {
-        ZM\Warning($ret[1]);
-        unset($user); // unset should be ok here because we aren't in a function
-        return;
-      }
-      $user = $ret[0];
-    } else if (!(empty($_REQUEST['username']) or empty($_REQUEST['password']))) {
-      # Longer versions are used on login page
-      $ret = validateUser($_REQUEST['username'], $_REQUEST['password']);
-      if (!$ret[0]) {
-        ZM\Warning($ret[1]);
-        unset($user); // unset should be ok here because we aren't in a function
-        return;
-      }
-      $user = $ret[0];
-
-      if (
-        defined('ZM_OPT_USE_GOOG_RECAPTCHA') && ZM_OPT_USE_GOOG_RECAPTCHA
-        && defined('ZM_OPT_GOOG_RECAPTCHA_SECRETKEY') && ZM_OPT_GOOG_RECAPTCHA_SECRETKEY
-        && defined('ZM_OPT_GOOG_RECAPTCHA_SITEKEY') && ZM_OPT_GOOG_RECAPTCHA_SITEKEY
-      ) {
-        if ( !isset($_REQUEST['g-recaptcha-response']) ) {
-          ZM\Error('reCaptcha authentication failed. No g-recpatcha-response in REQUEST: ');
+    if (empty($user)) {
+      if (ZM_AUTH_HASH_LOGINS && !empty($_REQUEST['auth'])) {
+        $user = getAuthUser($_REQUEST['auth']);
+      } else if (!(empty($_REQUEST['user']) or empty($_REQUEST['pass']))) {
+        # The shortened versions are used in auth_relay = PLAIN
+        $ret = validateUser($_REQUEST['user'], $_REQUEST['pass']);
+        if (!$ret[0]) {
+          ZM\Warning($ret[1]);
           unset($user); // unset should be ok here because we aren't in a function
           return;
         }
-        $url = 'https://www.google.com/recaptcha/api/siteverify';
-        $fields = array (
-          'secret'    => ZM_OPT_GOOG_RECAPTCHA_SECRETKEY,
-          'response'  => $_REQUEST['g-recaptcha-response'],
-          'remoteip'  => $_SERVER['REMOTE_ADDR']
-        );
-        $res = do_post_request($url, http_build_query($fields));
-        $responseData = json_decode($res, true);
-        // credit: https://github.com/google/recaptcha/blob/master/src/ReCaptcha/Response.php
-        // if recaptcha resulted in error, we might have to deny login
-        if ( isset($responseData['success']) && ($responseData['success'] == false) ) {
-          // PP - before we deny auth, let's make sure the error was not 'invalid secret'
-          // because that means the user did not configure the secret key correctly
-          // in this case, we prefer to let him login in and display a message to correct
-          // the key. Unfortunately, there is no way to check for invalid site key in code
-          // as it produces the same error as when you don't answer a recaptcha
-          if ( isset($responseData['error-codes']) && is_array($responseData['error-codes']) ) {
-            if ( !in_array('invalid-input-secret', $responseData['error-codes']) ) {
-              ZM\Error('reCaptcha authentication failed. response was: ' . print_r($responseData['error-codes'],true));
-              unset($user); // unset should be ok here because we aren't in a function
-              return;
-            } else {
-              ZM\Error('Invalid recaptcha secret detected');
-            }
+        $user = $ret[0];
+      } else if (!(empty($_REQUEST['username']) or empty($_REQUEST['password']))) {
+        # Longer versions are used on login page
+        $ret = validateUser($_REQUEST['username'], $_REQUEST['password']);
+        if (!$ret[0]) {
+          ZM\Warning($ret[1]);
+          unset($user); // unset should be ok here because we aren't in a function
+          return;
+        }
+        $user = $ret[0];
+
+        if (
+          defined('ZM_OPT_USE_GOOG_RECAPTCHA') && ZM_OPT_USE_GOOG_RECAPTCHA
+          && defined('ZM_OPT_GOOG_RECAPTCHA_SECRETKEY') && ZM_OPT_GOOG_RECAPTCHA_SECRETKEY
+          && defined('ZM_OPT_GOOG_RECAPTCHA_SITEKEY') && ZM_OPT_GOOG_RECAPTCHA_SITEKEY
+        ) {
+          if ( !isset($_REQUEST['g-recaptcha-response']) ) {
+            ZM\Error('reCaptcha authentication failed. No g-recpatcha-response in REQUEST: ');
+            unset($user); // unset should be ok here because we aren't in a function
+            return;
           }
-        } // end if success==false
-      } // end if using reCaptcha
+          $url = 'https://www.google.com/recaptcha/api/siteverify';
+          $fields = array (
+            'secret'    => ZM_OPT_GOOG_RECAPTCHA_SECRETKEY,
+            'response'  => $_REQUEST['g-recaptcha-response'],
+            'remoteip'  => $_SERVER['REMOTE_ADDR']
+          );
+          $res = do_post_request($url, http_build_query($fields));
+          $responseData = json_decode($res, true);
+          // credit: https://github.com/google/recaptcha/blob/master/src/ReCaptcha/Response.php
+          // if recaptcha resulted in error, we might have to deny login
+          if ( isset($responseData['success']) && ($responseData['success'] == false) ) {
+            // PP - before we deny auth, let's make sure the error was not 'invalid secret'
+            // because that means the user did not configure the secret key correctly
+            // in this case, we prefer to let him login in and display a message to correct
+            // the key. Unfortunately, there is no way to check for invalid site key in code
+            // as it produces the same error as when you don't answer a recaptcha
+            if ( isset($responseData['error-codes']) && is_array($responseData['error-codes']) ) {
+              if ( !in_array('invalid-input-secret', $responseData['error-codes']) ) {
+                ZM\Error('reCaptcha authentication failed. response was: ' . print_r($responseData['error-codes'],true));
+                unset($user); // unset should be ok here because we aren't in a function
+                return;
+              } else {
+                ZM\Error('Invalid recaptcha secret detected');
+              }
+            }
+          } // end if success==false
+        } // end if using reCaptcha
 
-      zm_session_clear(); # Closes session
-      zm_session_regenerate_id(); # starts session
+        zm_session_clear(); # Closes session
+        zm_session_regenerate_id(); # starts session
 
-      $username = $_REQUEST['username'];
-      $password = $_REQUEST['password'];
+        $username = $_REQUEST['username'];
+        $password = $_REQUEST['password'];
 
-      ZM\Info("Login successful for user \"$username\"");
-      $password_type = password_type($user->Password());
+        ZM\Info("Login successful for user \"$username\"");
+        $password_type = password_type($user->Password());
 
-      if ( $password_type == 'mysql' or $password_type == 'mysql+bcrypt' ) {
-        ZM\Info('Migrating password, if possible for future logins');
-        migrateHash($username, $password);
-      }
+        if ( $password_type == 'mysql' or $password_type == 'mysql+bcrypt' ) {
+          ZM\Info('Migrating password, if possible for future logins');
+          migrateHash($username, $password);
+        }
 
-      if (ZM_AUTH_TYPE == 'builtin') {
-        $_SESSION['passwordHash'] = $user->Password();
-      }
+        if (ZM_AUTH_TYPE == 'builtin') {
+          $_SESSION['passwordHash'] = $user->Password();
+        }
 
-      $_SESSION['username'] = $user->Username();
-      if (ZM_AUTH_RELAY == 'plain') {
-        // Need to save this in session, can't use the value in User because it is hashed
-        $_SESSION['password'] = $_REQUEST['password'];
-      }
-    } else if ((ZM_AUTH_TYPE == 'remote') and !empty($_SERVER['REMOTE_USER'])) {
-      if (ZM_CASE_INSENSITIVE_USERNAMES) {
-        $sql = 'SELECT * FROM Users WHERE Enabled=1 AND LOWER(Username)=LOWER(?)';
+        $_SESSION['username'] = $user->Username();
+        if (ZM_AUTH_RELAY == 'plain') {
+          // Need to save this in session, can't use the value in User because it is hashed
+          $_SESSION['password'] = $_REQUEST['password'];
+        }
+      } else if ((ZM_AUTH_TYPE == 'remote') and !empty($_SERVER['REMOTE_USER'])) {
+        if (ZM_CASE_INSENSITIVE_USERNAMES) {
+          $sql = 'SELECT * FROM Users WHERE Enabled=1 AND LOWER(Username)=LOWER(?)';
+        } else {
+          $sql = 'SELECT * FROM Users WHERE Enabled=1 AND Username=?';
+        }
+        // local user, shouldn't affect the global user
+        $user = new ZM\User(dbFetchOne($sql, NULL, array($_SERVER['REMOTE_USER'])));
       } else {
-        $sql = 'SELECT * FROM Users WHERE Enabled=1 AND Username=?';
+        $user = userFromSession();
       }
-      // local user, shouldn't affect the global user
-      $user = new ZM\User(dbFetchOne($sql, NULL, array($_SERVER['REMOTE_USER'])));
-    } else {
-      $user = userFromSession();
-    }
+    } // end if empty($user)
 
     if (!empty($user)) {
       // generate it once here, while session is open.  Value will be cached in session and return when called later on
