@@ -9,6 +9,7 @@ function MonitorStream(monitorData) {
   this.connKey = monitorData.connKey;
   this.url = monitorData.url;
   this.url_to_zms = monitorData.url_to_zms;
+  this.url_to_stream = monitorData.url_to_stream;
   this.width = monitorData.width;
   this.height = monitorData.height;
   this.RTSP2WebEnabled = monitorData.RTSP2WebEnabled;
@@ -331,17 +332,16 @@ function MonitorStream(monitorData) {
   };
 
   /*
-  * streamChannel = 0 || Primary; 1 || Secondary.
+  * streamChannel = 0 || Primary; 1 || Secondary.; 2 || Restream
   */
   this.start = function(streamChannel = 'default') {
     if (streamChannel === null || streamChannel === '' || currentView == 'montage') streamChannel = 'default';
-    if (!['default', 0, 1].includes(streamChannel)) {
+    if (!['default', 0, 1, 2].includes(streamChannel)) {
       streamChannel = (streamChannel.toLowerCase() == 'primary') ? 0 : 1;
     }
+    console.log('streamChannel', streamChannel);
     this.streamListenerBind = streamListener.bind(null, this);
 
-    console.log('start', this.Go2RTCEnabled, this.player);
-
     $j('#volumeControls').hide();
 
     if (this.Go2RTCEnabled && ((!this.player) || (-1 !== this.player.indexOf('go2rtc')))) {
@@ -356,6 +356,7 @@ function MonitorStream(monitorData) {
         const Go2RTCModUrl = url;
         const webrtcUrl = Go2RTCModUrl;
         this.currentChannelStream = (streamChannel == 'default') ? ((this.RTSP2WebStream == 'Secondary') ? 1 : 0) : streamChannel;
+        console.log(this.currentChannelStream);
         webrtcUrl.protocol = (url.protocol=='https:') ? 'wss:' : 'ws';
         webrtcUrl.pathname += "/ws";
         //webrtcUrl.search = 'src='+this.id;
@@ -700,7 +701,6 @@ function MonitorStream(monitorData) {
   };
 
   this.play = function() {
-    console.log('play');
     if ((this.activePlayer) && (-1 !== this.activePlayer.indexOf('go2rtc'))) {
       this.element.play(); // go2rtc player will handle mute
       this.statusCmdTimer = setInterval(this.statusCmdQuery.bind(this), statusRefreshTimeout);
@@ -1088,7 +1088,7 @@ function MonitorStream(monitorData) {
 
           if ((this.status.scale !== undefined) && (this.status.scale !== undefined) && (this.status.scale != this.scale)) {
             if (this.status.scale != 0) {
-              console.log("Stream not scaled, re-applying want:", this.scale, "current:", this.status.scale);
+              console.log("Stream not scaled on "+this.id+", re-applying want:", this.scale, "current:", this.status.scale);
               this.streamCommand({command: CMD_SCALE, scale: this.scale});
             }
           }
