@@ -405,7 +405,7 @@ $SLANG = array(
     'HasWhiteSpeed'         => '有白平衡速度',
     'HasZoomSpeed'          => '有缩放速度',
     'High'                  => '高',
-    'HighBW'                => '高&nbsp;B/W',
+    'Highband'                => '高&nbsp;B/W',
     'Home'                  => '主页',
     'Hostname'             => '主机名',               // Added - 2018-08-30
     'Hour'                  => '小时',
@@ -444,7 +444,7 @@ $SLANG = array(
     'Logout'                => '登出',
     'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                   => '低',
-    'LowBW'                 => '低&nbsp;B/W',
+    'Lowband'                 => '低&nbsp;B/W',
     'Main'                  => '主要',
     'Man'                   => '人',
     'Manual'                => '手册',
@@ -475,7 +475,7 @@ $SLANG = array(
     'MaxZoomStep'           => '最大缩放步进',
     'MaximumFPS'            => '最大帧率 FPS',
     'Medium'                => '中等',
-    'MediumBW'              => '中等&nbsp;B/W',
+    'Medband'              => '中等&nbsp;B/W',
     'Message'              => '消息',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'     => '最小报警区域应该小于最大区域',
     'MinAlarmAreaUnset'     => '您必须指定最小报警像素数量',
