@@ -18,10 +18,6 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
-if (!$user->canViewView('console')) {
-  $view = 'error';
-  return;
-}
 $canEditMonitors = canEdit('Monitors');
 $canCreateMonitors = canCreate('Monitors');
 
@@ -412,10 +408,16 @@ for ($monitor_i = 0; $monitor_i < count($displayMonitors); $monitor_i += 1) {
   if ((!$monitor['UpdatedOn']) or (strtotime($monitor['UpdatedOn']) < time()-$fps_report_seconds)) {
     echo translate('Offline').'<br/>';
   } else {
-    echo translate('Status'.$monitor['Status']).'<br/>';
+    echo 'Status: '.translate('Status'.$monitor['Status']).'<br/>';
+      echo translate('Capturing') . ': '.translate($monitor['Capturing']).'<br/>';
     if ($monitor['Analysing'] != 'None') {
       echo translate('Analysing') . ': '.translate($monitor['Analysing']).'<br/>';
     }
+    if ($monitor['ObjectDetection'] != 'none') {
+      echo translate('Object Detection') . ': '.translate($monitor['ObjectDetection']);
+      if ($monitor['AnalysisFPSLimit']) echo ' '.$monitor['AnalysisFPSLimit'].'fps';
+      echo '<br/>';
+    }
     if ($monitor['Recording'] != 'None') {
       echo translate('Recording') . ': '.translate($monitor['Recording']) . ($monitor['ONVIF_Event_Listener'] ? ' Use ONVIF' : "") . '<br/>';
     }
@@ -427,7 +429,8 @@ for ($monitor_i = 0; $monitor_i < count($displayMonitors); $monitor_i += 1) {
       $fps_string .= $monitor['CaptureFPS'];
     }
 
-    if ( isset($monitor['AnalysisFPS']) and ($monitor['Analysing'] != 'None')) {
+    if ( isset($monitor['AnalysisFPS'])) {
+     // and ($monitor['Analysing'] != 'None')) {
       $fps_string .= '/' . $monitor['AnalysisFPS'];
     $total_analysis_fps += $monitor['AnalysisFPS'];
     }
