@@ -610,7 +610,8 @@ function random_WebColour() {
 function buffer_setting_oninput(e) {
   const max_image_buffer_count = document.getElementById('newMonitor[MaxImageBufferCount]');
   const pre_event_count = document.getElementById('newMonitor[PreEventCount]');
-  if (parseInt(max_image_buffer_count.value) &&
+  if (parseInt(max_image_buffer_count.value)
+    &&
     (parseInt(pre_event_count.value) > parseInt(max_image_buffer_count.value))
   ) {
     if (this.id == 'newMonitor[PreEventCount]') {
@@ -714,7 +715,7 @@ function update_players() {
       ((-1 != key.indexOf('rtsp2web')) && !rtsp2web_enabled)
       ||
       ((-1 != key.indexOf('janus')) && !janus_enabled)
-      ) {
+    ) {
       console.log("not adding ", key, go2rtc_enabled, rtsp2web_enabled, janus_enabled);
     } else {
       dropdown.append($j('<option></option>').attr('value', key).text(entry));
@@ -839,7 +840,7 @@ function ControlList_onClick() {
 
 function ObjectDetection_onChange(od_select) {
   const od = od_select.value;
-  if (od ==  'none') {
+  if (od == 'none') {
     // Hide other options
     $j('#ObjectDetectionModel').hide();
     $j('#ObjectDetectionObjectThreshold').hide();
@@ -856,7 +857,7 @@ function ObjectDetection_onChange(od_select) {
 
     od_model_select.innerHTML = '';
     for (const [key, value] of Object.entries(od_models[od])) {
-      let opt = document.createElement('option');
+      const opt = document.createElement('option');
       opt.value = key; // the index
       opt.innerHTML = value;
       od_model_select.append(opt);
