@@ -905,7 +905,7 @@ function watchFullscreen() {
 
 function initGridStack(grid=null) {
   const opts = {
-    margin: '0 1px 0 1px',
+    margin: '0 0px 0 0px',
     cellHeight: '4px', //Required for correct use of objGridStack.resizeToContent
     sizeToContent: true, // default to make them all fit
     resizable: {handles: 'all'}, // do all sides
@@ -1231,22 +1231,12 @@ document.onvisibilitychange = () => {
   }
 };
 
-
-/*
+// This is to stop the streams in a nicer way (no broken image) and hopefully faster.
 window.onbeforeunload = function(e) {
-  console.log('unload');
-  //event.preventDefault();
   for (let i = 0, length = monitorData.length; i < length; i++) {
     monitors[i].kill();
   }
+  return;
+  // Returning any value here, including undefined causes an undesired popup.
   var e = e || window.event;
-
-  // For IE and Firefox
-  if (e) {
-    e.returnValue = undefined;
-  }
-
-  // For Safari
-  return undefined;
 };
-*/
