@@ -611,9 +611,9 @@ function drawGraph() {
 
   /* Clear timeline */
   if (0) {
-  ctx.fillStyle = '#000000';
-  ctx.globalAlpha = 1;
-  ctx.fillRect(0, 0, cWidth, cHeight);
+    ctx.fillStyle = '#000000';
+    ctx.globalAlpha = 1;
+    ctx.fillRect(0, 0, cWidth, cHeight);
   }
 
   rowHeight = parseInt(cHeight / (numMonitors + 1) ); // Leave room for a scale of some sort
@@ -1308,9 +1308,8 @@ function initPage() {
       alert("Couldn't find DOM element for Monitor" + monId + "monitorPtr.length=" + len);
       continue;
     }
-    console.log("Setting up imagedone for ", monId);
-    monitorCanvasCtx[monId] = monitorCanvasObj[monId].getContext('2d');
-
+    canvasObj.addEventListener('click', clickMonitor, false);
+    monitorCanvasCtx[monId] = canvasObj.getContext('2d');
     const imageObject = monitorImageObject[monId] = new Image();
     imageObject.monId = monId;
     imageObject.onload = function() {
@@ -1322,7 +1321,6 @@ function initPage() {
     if (liveMode) {
       loadImage2Monitor(monId, monitorImageURL[monId]);
     }
-    canvasObj.addEventListener('click', clickMonitor, false);
   } // end foreach monitor
 
   setSpeed(speedIndex);
