@@ -1358,7 +1358,9 @@ function monitorsSetScale(id=null) {
       var currentMonitor = monitorStream;
     } else if (typeof monitors !== 'undefined') {
       //used on Montage, Watch & Event page.
-      var currentMonitor = monitors.find((o) => { return parseInt(o["id"]) === id; });
+      var currentMonitor = monitors.find((o) => {
+        return parseInt(o["id"]) === id;
+      });
     } else {
       //Stream is missing
       return;
