@@ -4,7 +4,10 @@ var saveBtn = $j('#saveBtn');
 var cancelBtn = $j('#cancelBtn');
 var backBtn = $j('#backBtn');
 var refreshBtn = $j('#refreshBtn');
+var analyseBtn = $j('#analyseBtn');
 var monitors = [];
+var analyse_frames = true;
+var TimerHideShow;
 
 function validateForm( form ) {
   var errors = [];
@@ -232,7 +235,7 @@ function applyZoneUnits() {
 function limitRange(field, minValue, maxValue) {
   if ( field.value != '' ) {
     field.value = constrainValue(
-        parseInt(field.value),
+        parseFloat(field.value),
         parseInt(minValue),
         parseInt(maxValue)
     );
@@ -322,27 +325,27 @@ function constrainValue(value, loVal, hiVal) {
 }
 
 function updateActivePoint(index) {
-  var point = $j('#point'+index);
-  var imageFrame = document.getElementById('imageFrame'+monitorId);
-  var style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
-  var padding_left = parseInt(style.paddingLeft);
-  var padding_top = parseInt(style.paddingTop);
-  var padding_right = parseInt(style.paddingRight);
-  var scale = (imageFrame.clientWidth - ( padding_top + padding_right )) / maxX;
-  var left = parseInt(point.css('left'), 10);
+  const point = $j('#point'+index);
+  const imageFrame = document.getElementById('imageFrame');
+  const style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
+  const padding_left = parseInt(style.paddingLeft);
+  const padding_top = parseInt(style.paddingTop);
+  const padding_right = parseInt(style.paddingRight);
+  const scale = (imageFrame.clientWidth - ( padding_left + padding_right )) / maxX;
 
-  if ( left < padding_left ) {
+  let point_left = parseInt(point.css('left'), 10);
+  if ( point_left < padding_left ) {
     point.css('left', style.paddingLeft);
-    left = parseInt(padding_left);
+    point_left = parseInt(padding_left);
   }
-  var top = parseInt(point.css('top'));
-  if ( top < padding_top ) {
+  let point_top = parseInt(point.css('top'));
+  if ( point_top < padding_top ) {
     point.css('top', style.paddingTop);
-    top = parseInt(padding_top);
+    point_top = parseInt(padding_top);
   }
 
-  var x = constrainValue(Math.ceil(left / scale)-Math.ceil(padding_left/scale), 0, maxX);
-  var y = constrainValue(Math.ceil(top / scale)-Math.ceil(padding_top/scale), 0, maxY);
+  var x = constrainValue(Math.ceil(point_left / scale)-Math.ceil(padding_left/scale), 0, maxX);
+  var y = constrainValue(Math.ceil(point_top / scale)-Math.ceil(padding_top/scale), 0, maxY);
 
   zone['Points'][index].x = document.getElementById('newZone[Points]['+index+'][x]').value = x;
   zone['Points'][index].y = document.getElementById('newZone[Points]['+index+'][y]').value = y;
@@ -391,14 +394,15 @@ function updateArea( ) {
   }
 }
 
+/* Updates the drawn point based on input from the coordinates text inputs */
 function updateX(input) {
   const index = input.getAttribute('data-point-index');
 
   limitPointValue(input, 0, maxX);
 
   const point = $j('#point'+index);
-  const x = parseInt(input.value);
-  const imageFrame = document.getElementById('imageFrame'+monitorId);
+  const x = input.value;
+  const imageFrame = document.getElementById('imageFrame');
   const style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
   const padding_left = parseInt(style.paddingLeft);
   const padding_right = parseInt(style.paddingRight);
@@ -411,13 +415,14 @@ function updateX(input) {
   updateArea();
 }
 
+/* Updates the drawn point based on input from the coordinates text inputs */
 function updateY(input) {
   const index = input.getAttribute('data-point-index');
   limitPointValue(input, 0, maxY);
 
   const point = $j('#point'+index);
   const y = input.value;
-  const imageFrame = document.getElementById('imageFrame'+monitorId);
+  const imageFrame = document.getElementById('imageFrame');
   const style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
   const padding_left = parseInt(style.paddingLeft);
   const padding_right = parseInt(style.paddingRight);
@@ -446,11 +451,7 @@ function saveChanges(element) {
 }
 
 function drawZonePoints() {
-  var imageFrame = document.getElementById('imageFrame'+monitorId);
-  if (!imageFrame) {
-    console.log("No imageFrame for " + monitorId);
-    return;
-  }
+  var imageFrame = document.getElementById('imageFrame');
   $j('.zonePoint').remove();
   var style = imageFrame.currentStyle || window.getComputedStyle(imageFrame);
   var padding_left = parseInt(style.paddingLeft);
@@ -474,7 +475,7 @@ function drawZonePoints() {
     div.mouseover(highlightOn.bind(i, i));
     div.mouseout(highlightOff.bind(i, i));
 
-    $j(imageFrame).append(div);
+    $j('#imageFrame').append(div);
 
     div.draggable({
       'containment': document.getElementById('imageFeed'+zone.MonitorId),
@@ -552,7 +553,7 @@ function drawZonePoints() {
   } // end foreach point
   // Sets up the SVG polygon
   updateZoneImage();
-}
+} // end drawZonePoints()
 
 function streamCmdPause() {
   for ( var i = 0, length = monitors.length; i < length; i++ ) {
@@ -583,12 +584,13 @@ function watchdogCheck(type) {
 function watchdogOk(type) {
   watchdogInactive[type] = false;
 }
+
 function presetSelectorBlur() {
   this.selectedIndex = 0;
 }
 
 function initPage() {
-  var form = document.zoneForm;
+  const form = document.zoneForm;
 
   //form.elements['newZone[Name]'].disabled = true;
   //form.elements['newZone[Type]'].disabled = true;
@@ -608,7 +610,7 @@ function initPage() {
     'newAlarmRgbB',
   ].forEach(
       function(element_name, index) {
-        var el = form.elements[element_name];
+        const el = form.elements[element_name];
         if ( el ) {
           el.oninput = window['limitRangeToUnsignedByte'].bind(el, el);
           el.disabled = true;
@@ -621,7 +623,7 @@ function initPage() {
     'newZone[FilterY]'
   ].forEach(
       function(element_name, index) {
-        var el = form.elements[element_name];
+        const el = form.elements[element_name];
         if ( el ) {
           el.oninput = window['limitFilter'].bind(el, el);
           el.disabled = true;
@@ -636,7 +638,7 @@ function initPage() {
     'newZone[MinFilterPixels]',
     'newZone[MaxFilterPixels]'
   ].forEach(function(element_name, index) {
-    var el = form.elements[element_name];
+    const el = form.elements[element_name];
     if ( el ) {
       el.oninput = window['limitArea'].bind(el, el);
       el.disabled = true;
@@ -676,16 +678,34 @@ function initPage() {
     };
   }
 
-  for ( var i = 0, length = monitorData.length; i < length; i++ ) {
-    monitors[i] = new MonitorStream(monitorData[i]);
-
-    // Start the fps and status updates. give a random delay so that we don't assault the server
-    var delay = Math.round( (Math.random()+0.5)*statusRefreshTimeout );
-    monitors[i].setScale('0');
-    monitors[i].start(delay);
+  if ( el = analyseBtn[0] ) {
+    el.onclick = function() {
+      analyse_frames = !analyse_frames;
+      if (analyse_frames) {
+        analyseBtn.addClass('btn-primary');
+        analyseBtn.removeClass('btn-secondary');
+        analyseBtn.attr('title', translate['Showing Analysis']);
+      } else {
+        analyseBtn.removeClass('btn-primaryary');
+        analyseBtn.addClass('btn-secondary');
+        analyseBtn.attr('title', translate['Not Showing Analysis']);
+      }
+      for ( var i = 0, length = monitors.length; i < length; i++ ) {
+        monitors[i].show_analyse_frames(analyse_frames);
+      }
+    };
+  } else {
+    console.log('Analyse button not found');
   }
 
-  document.querySelectorAll('.imageFrame img').forEach(function(el) {
+  for ( var i = 0, length = monitorData.length; i < length; i++ ) {
+    monitors[i] = new MonitorStream(monitorData[i]);
+    monitors[i].setStreamScale();
+    monitors[i].show_analyse_frames(analyse_frames);
+    monitors[i].start();
+  }
+
+  document.querySelectorAll('#imageFrame img').forEach(function(el) {
     el.addEventListener("load", imageLoadEvent, {passive: true});
   });
   window.addEventListener("resize", drawZonePoints, {passive: true});
@@ -708,10 +728,18 @@ function initPage() {
   });
 } // initPage
 
+function panZoomIn(el) {
+  zmPanZoom.zoomIn(el);
+}
+
+function panZoomOut(el) {
+  zmPanZoom.zoomOut(el);
+}
+
 function imageLoadEvent() {
   // We only need this event on the first image load to set dimensions.
   // Turn it off after it has been called.
-  document.querySelectorAll('.imageFrame img').forEach(function(el) {
+  document.querySelectorAll('#imageFrame img').forEach(function(el) {
     el.removeEventListener("load", imageLoadEvent, {passive: true});
   });
   drawZonePoints();
@@ -731,4 +759,23 @@ function Polygon_calcArea(coords) {
   return Math.round(Math.abs(float_area));
 }
 
+document.onvisibilitychange = () => {
+  if (document.visibilityState === "hidden") {
+    TimerHideShow = clearTimeout(TimerHideShow);
+    TimerHideShow = setTimeout(function() {
+      //Stop monitors when closing or hiding page
+      for (let i = 0, length = monitorData.length; i < length; i++) {
+        monitors[i].kill();
+      }
+    }, 15*1000);
+  } else {
+    //Start monitors when show page
+    for (let i = 0, length = monitorData.length; i < length; i++) {
+      if (!monitors[i].started) {
+        monitors[i].start();
+      }
+    }
+  }
+};
+
 window.addEventListener('DOMContentLoaded', initPage);
