@@ -845,20 +845,16 @@ include('_monitor_source_nvsocket.php');
 <?php
 $decoders = array(
   'auto' => translate('Auto'),
-  'mjpeg' => 'mjpeg',
-  'jpeg_ni_quadra_dec' => 'jpeg_ni_quadra_dec',
   'libx264' => 'libx264',
   'h264' => 'h264',
   'h264_cuvid' => 'h264_cuvid',
   'h264_nvmpi' => 'h264_nvmpi',
   'h264_mmal'   => 'h264_mmal',
-  'h264_ni_quadra_dec' => 'h264_ni_quadra',
   'h264_omx' => 'h264_omx',
   'h264_qsv' => 'h264_qsv',
   'h264_vaapi' => 'h264_vaapi',
   'h264_v4l2m2m' => 'h264_v4l2m2m',
   'libx265' => 'libx265',
-  'h265_ni_quadra_dec' => 'h265_ni_quadra',
   'hevc_cuvid' => 'hevc_cuvid',
   'hevc_nvmpi' => 'hevc_nvmpi',
   'hevc_qsv' => 'hevc_qsv',
@@ -867,7 +863,6 @@ $decoders = array(
   'vp9_qsv' => 'vp9-qsv',
   'vp9_cuvid' => 'vp9_cuvid',
   'vp9_nvmpi' => 'vp9_nvmpi',
-  'vp9_ni_quadra_dec' => 'vp9_ni_quadra',
   'vp9_v4l2m2m' => 'vp9_v4l2m2m',
   'libsvtav1' => 'libsvtav1',
   'libaom-av1'  => 'libaom-av1',
@@ -875,8 +870,6 @@ $decoders = array(
   'av1' => 'av1',
   'av1_qsv' => 'av1_qsv',
   'av1_cuvid' => 'av1_cuvid',
-  'av1_vaapi' => 'av1_vaapi'
-  #'av1_ni_quadra_dec' => 'av1_ni_quadra',
 );
 echo htmlSelect('newMonitor[Decoder]', $decoders, $monitor->Decoder());
 ?>
@@ -1073,64 +1066,6 @@ echo htmlSelect('newMonitor[Decoder]', $decoders, $monitor->Decoder());
               <input type="text" name="newMonitor[LinkedMonitors]" value="<?php echo $monitor->LinkedMonitors() ?>" data-on-input="updateLinkedMonitorsUI"/><br/>
               <div id="LinkedMonitorsUI"></div>
             </li>
-            <li class="ObjectDetection">
-              <label><?php echo translate('Object Detection')?></label>
-<?php
-        $od_options = ['none'=>'None', 'uvicorn'=>'Yolo 11 on Ampere CPU'];
-        if (defined('HAVE_UNTETHER'))
-          $od_options['speedai'] = 'Untether SpeedAI';
-        if (defined('HAVE_QUADRA'))
-          $od_options['quadra'] = 'NetInt Quadra';
-        if (defined('HAVE_MEMX'))
-          $od_options['memx'] = 'MemryX Local MX3';
-        if (defined('HAVE_MX_ACCL'))
-          $od_options['mx_accl'] = 'MemryX MxAccl';
-
-        echo htmlSelect('newMonitor[ObjectDetection]', $od_options, $monitor->ObjectDetection(), [ 'data-on-change-this'=>'ObjectDetection_onChange']);
-?>
-            </li>
-<?php if (defined('HAVE_UNTETHER') or defined('HAVE_QUADRA')) { ?>
-            <li id="ObjectDetectionModel" class="ObjectDetectionModel">
-              <label><?php echo translate('Object Detection Model')?></label>
-<?php
-        $models = ['none'=>[]];
-        foreach (glob(ZM_DIR_MODELS.'/*') as $model) {
-          $model = basename($model);
-          $extension = pathinfo($model, PATHINFO_EXTENSION);
-          if ($extension == 'dfp') {
-            if (defined('HAVE_MEMX')) {
-              if (!isset($models['memx'])) $models['memx'] = [];
-              $models['memx'][$model] = $model;
-            }
-            if (defined('HAVE_MX_ACCL')) {
-              if (!isset($models['mx_accl'])) $models['mx_accl'] = [];
-              $models['mx_accl'][$model] = $model;
-            }
-          } else if ($extension == 'uxf' and defined('HAVE_UNTETHER')) {
-            if (!isset($models['speedai'])) $models['speedai'] = [];
-            $models['speedai'][$model] = $model;
-          } else if ($extension == 'nb' and defined('HAVE_QUADRA')) {
-            if (!isset($models['quadra'])) $models['quadra'] = [];
-            $models['quadra'][$model] = $model;
-          } else {
-            ZM\Debug("Unkown extension in model $model");
-          }
-          if ($monitor->ObjectDetection() == 'none') {
-            $models['none'][$model] = $model;
-          }
-        }
-          echo htmlSelect('newMonitor[ObjectDetectionModel]', $models[$monitor->ObjectDetection()], $monitor->ObjectDetectionModel());
-?>
-            </li>
-            <li id="ObjectDetectionObjectThreshold" class="ObjectDetectionObjectThreshold">
-              <label><?php echo translate('Object Detection Object Threshold')?></label>
-              <input type="number" name="newMonitor[ObjectDetectionObjectThreshold]" value="<?php echo validHtmlStr($monitor->ObjectDetectionObjectThreshold()) ?>" min="0" step="any" max="100"/>
-            </li>
-            <li id="ObjectDetectionNMSThreshold" class="ObjectDetectionNMSThreshold">
-              <label><?php echo translate('Object Detection NMS Threshold')?></label>
-              <input type="number" name="newMonitor[ObjectDetectionNMSThreshold]" value="<?php echo validHtmlStr($monitor->ObjectDetectionNMSThreshold()) ?>" min="0" step="any" max="100"/>
-            </li>
-<?php } ?>
             <li id="function_use_Amcrest_API" class="use_Amcreat_API">
               <label><?php echo translate('use_Amcrest_API') ?></label>
               <?php echo html_radio('newMonitor[use_Amcrest_API]', array('1'=>translate('Enabled'), '0'=>translate('Disabled')), $monitor->use_Amcrest_API()); ?>
@@ -1228,13 +1163,11 @@ $videowriter_encoders = array(
   'libx264' => 'libx264',
   'h264' => 'h264',
   'h264_nvenc' => 'h264_nvenc',
-  'h264_ni_quadra_enc' => 'h264_ni_quadra',
   'h264_omx' => 'h264_omx',
   'h264_qsv' => 'h264_qsv',
   'h264_vaapi' => 'h264_vaapi',
   'h264_v4l2m2m' => 'h264_v4l2m2m',
   'libx265' => 'libx265',
-  'h265_ni_quadra_enc' => 'h265_ni_quadra',
   'hevc_nvenc' => 'hevc_nvenc',
   'hevc_qsv' => 'hevc_qsv',
   'hevc_vaapi' => 'hevc_vaapi',
@@ -1243,7 +1176,6 @@ $videowriter_encoders = array(
   'libsvtav1' => 'libsvtav1',
   'libaom-av1'  => 'libaom-av1',
   'av1_qsv' => 'av1_qsv',
-  'av1_ni_quadra_enc' => 'av1_ni_quadra',
   'av1_vaapi' => 'av1_vaapi',
   'av1_nvenc' => 'av1_nvenc'
 );
@@ -1465,7 +1397,7 @@ $codecs = array(
 ?>
             <li>
               <label><?php echo translate('TimestampLabelFormat') ?></label>
-              <input type="text" name="newMonitor[LabelFormat]" value="<?php echo validHtmlStr($monitor->LabelFormat()) ?>" placeholder="<?php echo translate('Python strftime format. %f for hundredths, %N for Monitor Name, %Q for show text. A good default is %N - %d/%m/%y %H:%M:%S') ?>"/>
+              <input type="text" name="newMonitor[LabelFormat]" value="<?php echo validHtmlStr($monitor->LabelFormat()) ?>" placeholder="<?php echo translate('Python strftime format. %f for hundredths, %N for Monitor Name, %Q for show text.') ?>"/>
             </li>
             <li>
               <label><?php echo translate('TimestampLabelX') ?></label>
