@@ -117,7 +117,7 @@ if (isset($_REQUEST['zmMontageLayout'])) {
   $layout_id = validCardinal($_SESSION['zmMontageLayout']);
 }
 if (!$layout_id || !isset($layoutsById[$layout_id])) {
-  $layout_id = $layoutsByName['Auto']->Id();
+  $layout_id = isset( $layoutsByName['Auto']) ? $layoutsByName['Auto']->Id() : 0;
 }
 $layout = $layoutsById[$layout_id];
 $layout_is_preset = array_search($layout->Name(), $presetLayoutsNames) === false ? false : true;
@@ -242,7 +242,7 @@ if ($monitorCount <= 3) {
 $AutoLayoutName = $default_layout;
 
 xhtmlHeadersStart(__FILE__, translate('Montage'));
-echo output_link(array('/assets/gridstack-11.1.2/dist/gridstack.css', '/assets/gridstack-11.1.2/dist/gridstack-extra.css'));
+echo output_link(array('/assets/gridstack-12.3.3/dist/gridstack.css', '/assets/gridstack-12.3.3/dist/gridstack-extra.css'));
 xhtmlHeadersEnd(__FILE__, translate('Montage'));
 getBodyTopHTML();
 echo getNavBarHTML();
@@ -313,18 +313,6 @@ echo htmlSelect('changeRate', $maxfps_options, $options['maxfps'], array('id'=>'
             <label for="streamQuality"><?php echo translate('Stream quality') ?></label>
             <?php echo htmlSelect('streamQuality', $streamQuality, $streamQualitySelected, array('data-on-change'=>'changeStreamQuality','id'=>'streamQuality', 'class'=>'chosen')); ?>
           </span>
-          <span id="widthControl" class="hidden"> <!-- OLD version, requires removal -->
-            <label><?php echo translate('Width') ?></label>
-            <?php echo htmlSelect('width', $widths, 'auto'/*$options['width']*/, array('id'=>'width', 'data-on-change'=>'changeWidth', 'class'=>'chosen')); ?>
-          </span>
-          <span id="heightControl" class="hidden"> <!-- OLD version, requires removal -->
-            <label><?php echo translate('Height') ?></label>
-            <?php echo htmlSelect('height', $heights, 'auto'/*$options['height']*/, array('id'=>'height', 'data-on-change'=>'changeHeight', 'class'=>'chosen')); ?>
-          </span>
-          <span id="scaleControl" class="hidden"> <!-- OLD version, requires removal -->
-            <label><?php echo translate('Scale') ?></label>
-            <?php echo htmlSelect('scale', $scales, '0'/*$scale*/, array('id'=>'scale', 'data-on-change-this'=>'changeScale', 'class'=>'chosen')); ?>
-          </span> 
           <span id="layoutControl">
             <label for="zmMontageLayout"><?php echo translate('Layout') ?></label>
             <?php echo htmlSelect('zmMontageLayout', $layoutsById, $layout_id, array('id'=>'zmMontageLayout', 'data-on-change'=>'selectLayout', 'class'=>'chosen')); ?>
@@ -392,8 +380,8 @@ foreach ($monitors as $monitor) {
       $monitor_options['scale'] = intval(100*(($browser_width/4)/$monitor->Width()));
       if ($monitor_options['scale'] > 100) $monitor_options['scale'] = 100;
       if ($monitor_options['scale'] < 10) $monitor_options['scale'] = 10;
-      $monitor->initial_scale($monitor_options['scale']);
     }
+    $monitor->initial_scale($monitor_options['scale']);
     echo $monitor->getStreamHTML($monitor_options);
   }
 } # end foreach monitor
@@ -430,7 +418,7 @@ foreach ($monitors as $monitor) {
   </div>
 </div>
 <?php
-  echo '<script src="skins/'.$skin.'/assets/gridstack-11.1.2/dist/gridstack-all.js"></script>';
+  echo '<script src="skins/'.$skin.'/assets/gridstack-12.3.3/dist/gridstack-all.js"></script>';
   echo output_script_if_exists(array('assets/jquery.panzoom/dist/jquery.panzoom.js'));
   echo output_script_if_exists(array('js/panzoom.js'));
   echo '<script type="module" src="js/video-stream.js"></script>'.PHP_EOL;
