@@ -18,7 +18,7 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
-if (!canView('Stream') or !$user->canViewView('watch')) {
+if (!canView('Stream')) {
   $view = 'error';
   return;
 }
@@ -269,7 +269,7 @@ echo getNavBarHTML() ?>
     }
 ?>
 >
-            <span class="material-icons md-18">open_with</span>
+          <span class="material-icons md-18">open_with</span>
         </button>
       </div>
       <div class="form-check control-use-old-zoom-pan">
@@ -395,12 +395,6 @@ echo htmlSelect('cyclePeriod', $cyclePeriodOptions, $period, array('id'=>'cycleP
     }
     echo '<li id="nav-item-cycle'.$m->Id().'" class="nav-item"><a id="nav-link'.$m->Id().'" class="nav-link'.( $m->Id() == $monitor->Id() ? ' active' : '' ).'" data-monIdx='.$dataMonIdx++.' href="#">'.$m->Name().'</a></li>';
   }
-  if ($monitorJanusUsed) {
-?>
-    <script src="<?php echo cache_bust('js/adapter.min.js') ?>"></script>
-    <script src="/javascript/janus/janus.js"></script>
-<?php
-  }
  ?>
           </ul>
         </nav>
@@ -530,7 +524,7 @@ if ( canView('Events') && ($monitor->Type() != 'WebSite') ) {
     </div><!-- id="content" -->
   </div>
 </div>
-  <script src="<?php echo cache_bust('js/hls-1.5.20/hls.min.js') ?>"></script>
+  <script src="<?php echo cache_bust('js/hls-1.6.13/hls.min.js') ?>"></script>
 <?php
   } else {
     echo "There are no monitors to display\n";
