@@ -41,13 +41,13 @@ $Event = null;
 
 if ( ! empty($_REQUEST['eid']) ) {
   $Event = new ZM\Event($_REQUEST['eid']);
-  $path = $Event->Path().'/'.$Event->DefaultVideo();
+  $path = (mb_substr($Event->DefaultVideo(), 0, 1) == '/' ) ? $Event->DefaultVideo() : $Event->Path().'/'.$Event->DefaultVideo();
 } else if ( ! empty($_REQUEST['event_id']) ) {
   $Event = new ZM\Event($_REQUEST['event_id']);
   if (!empty($_REQUEST['file'])) {
     $path = $Event->Path().'/'.preg_replace('/\//', '', $_REQUEST['file']);
   } else {
-    $path = $Event->Path().'/'.$Event->DefaultVideo();
+    $path = (mb_substr($Event->DefaultVideo(), 0, 1) == '/' ) ? $Event->DefaultVideo() : $Event->Path().'/'.$Event->DefaultVideo();
   }
 } else {
   $errorText = 'No video path';
@@ -84,7 +84,8 @@ if ( isset($_SERVER['HTTP_RANGE']) ) {
   }
 } # end if HTTP_RANGE
 
-header('Content-type: video/mp4');
+$path_info = pathinfo($Event->DefaultVideo());
+header('Content-type: video/'.$path_info['extension']);
 header('Accept-Ranges: bytes');
 header('Content-Length: '.$length);
 # This is so that Save Image As give a useful filename
